@@ -75,7 +75,7 @@ void FavoriteListView::update()
         const Kita::Thread* thread = Kita::Thread::getByURL( *it );
 
         QDateTime since;
-        since.setTime_t( KURL( thread->datURL() ).fileName().section( '.', 0, 0 ).toInt() );
+        since.setTime_t( Kita::datToSince( thread->datURL() ) );
 
         int readNum = cache->readNum( thread->datURL() );
         int resNum = KitaThreadInfo::resNum( thread->datURL() );
@@ -93,6 +93,7 @@ void FavoriteListView::update()
         item->setText( Col_Since, since.toString( "yy/MM/dd hh:mm" ) );
         item->setText( Col_DatURL, thread->datURL() );
     }
+    subjectList->setSorting( Col_Board );
 }
 
 void FavoriteListView::loadThread( QListViewItem* item )
