@@ -21,6 +21,7 @@
 #include <kdebug.h>
 #include <qvaluelist.h>
 #include <qheader.h>
+#include <kstandarddirs.h>
 
 #include "kitaboardview.h"
 #include "kita.h"
@@ -139,9 +140,45 @@ void KitaBoardView::loadBoardList()
         previous = categoryItem;
     }
 
+    loadExtBoard();
     refreshFavoriteBoards();
 }
 
+
+/* private */
+void KitaBoardView::loadExtBoard()
+{
+    QString configPath = locateLocal( "appdata", "extbrd.conf" );
+    QFile file( configPath );
+    if ( file.open( IO_ReadOnly ) ) {
+
+	QTextStream stream( &file );
+	stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+	QStringList list;
+	QString str;
+
+	KListViewItem* categoryItem = new KListViewItem( m_boardList, "extboard" );
+	
+	while ( ( str = stream.readLine() ) != QString::null ){
+	    if ( ! str.isEmpty() ){
+		QStringList list = QStringList::split( "<>", str );
+
+		if ( list.size() == 2 ){		
+		    QString board_title = list[ 0 ];
+		    QString board_url = list[ 1 ];
+
+		    new KListViewItem( categoryItem, board_title, board_url );
+		    Kita::Board::setName( board_url, board_title );
+		}
+	    }
+	}
+
+	file.close();
+    }
+}
+
+
 QValueList<Kita::Category> KitaBoardView::getCategoryList( const QString& html ) const
 {
     QValueList<Kita::Category> result;
@@ -214,6 +251,13 @@ void KitaBoardView::setFont( const QFont& font )
     m_boardList->setFont( font );
 }
 
+/* public slot :*/ /* virtual */
+void KitaBoardView::setFocus()
+{
+    m_boardList->setFocus();
+}
+
+
 void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint& point, int )
 {
     if ( item == 0 ) {
