@@ -53,7 +53,11 @@ public:
 public slots:
     void loadBoardList();
     void setFont( const QFont& font );
+    virtual void setFocus();    
 
+private:
+    void loadExtBoard();
+    
 signals:
     void openBoardRequested( const QString& boardURL, bool withNewTab );
     void sigShowSubject();    
