@@ -11,8 +11,7 @@
 #ifndef KITASUBJECTTABWIDGET_H
 #define KITASUBJECTTABWIDGET_H
 
-#include <qtabwidget.h>
-#include <qtabbar.h>
+#include "kitatabwidgetbase.h"
 
 #include "favoritelistview.h"
 #include "kitasubjectview.h"
@@ -20,7 +19,7 @@
 /**
 @author Hideki Ikemoto
 */
-class KitaSubjectTabWidget : public QTabWidget
+class KitaSubjectTabWidget : public KitaTabWidgetBase
 {
     Q_OBJECT
 
@@ -30,7 +29,6 @@ public:
 
 public slots:
     void loadBoard( const QString&, bool withNewTab = false );
-    void reloadSubjectList();
 
 private:
     FavoriteListView* m_favoriteList;
@@ -38,34 +36,62 @@ private:
     QPtrList<KitaSubjectView> m_viewList;
     void connectSignals( Kita::ThreadListView* );
     KitaSubjectView* findView( const QString& boardURL );
+    KitaSubjectView* isSubjectView( QWidget* w );
+    void setupActions();
 
 private slots:
     void slotCurrentChanged( QWidget* widget );
-    void deleteView( KitaSubjectView* view );
-    void slotSwitchSubjectView();
+    void slotReloadButton();
+    void slotFocusSearchCombo();
+
+
+protected:
+    virtual void deleteWidget( QWidget* w );
 
 signals:
     void showThreadRequested( const QString&, bool withNewTab );
-    void loadBoardCompleted( const KURL& );
-    void switchSubjectView();
 };
 
-namespace Kita
+/*--------------------------------------------------*/
+
+class SubjectTabBar : public KitaTabBarBase
 {
-    class SubjectTabBar : public QTabBar
-    {
-        Q_OBJECT
+    Q_OBJECT
 
-    public:
-        SubjectTabBar( QWidget* parent = 0, const char* name = 0 );
-        ~SubjectTabBar();
+public:
+    SubjectTabBar( QWidget* parent = 0, const char* name = 0 );
+    ~SubjectTabBar();
+
+private:
+    virtual void showPopupMenu( int idx, QPoint global );
+
+};
+
+
+/*--------------------------------------------------*/
+
+
+class KitaSubjectDock : public KitaDockWidgetBase
+{
+
+    Q_OBJECT
+    KitaSubjectTabWidget* m_subjectTab;
+public:
+    KitaSubjectDock( KDockManager* dockManager,
+                     const char* name,
+                     const QPixmap &pixmap,
+                     QWidget* parent = 0L,
+                     const QString& strCaption = QString::null,
+                     const QString& strTabPageLabel = QString::fromLatin1( " " ),
+                     WFlags f = 0 );
+    ~KitaSubjectDock();
+
+    KitaSubjectTabWidget* setup();
+
+public slots:
+    void slotLoadBoard( const QString& boardURL, bool withNewTab );
+};
 
-    protected:
-        virtual void contextMenuEvent( QContextMenuEvent* e );
 
-    signals:
-        void deleteMenuSelected( KitaSubjectView* );
-    };
-}
 
 #endif
