@@ -21,6 +21,7 @@
 #include <qdatetime.h>
 #include <qlabel.h>
 #include <qmessagebox.h>
+#include <qcombobox.h>
 
 // kdelibs/kio
 #include <kio/slaveconfig.h>
@@ -62,6 +63,8 @@ KitaSubjectView::KitaSubjectView( QWidget* parent, const char* name )
              SLOT( slotUpdateSubject( const KURL& ) ) );
     connect( this, SIGNAL( closeThreadTab( const KURL& ) ),
 	     signalCollection, SIGNAL( closeThreadTab( const KURL& ) ));
+    connect( this, SIGNAL( loadBoardCompleted( const KURL& ) ),
+	     signalCollection, SIGNAL( setMainURLLine( const KURL& ) ));
 }
 
 KitaSubjectView::~KitaSubjectView()
@@ -145,9 +148,11 @@ void KitaSubjectView::loadBoard( const QString& boardURL )
 
         QDateTime since;
         since.setTime_t( Kita::datToSince( thread->datURL() ) );
+        QDateTime current = QDateTime::currentDateTime();
 
         int readNum = cache->readNum( thread->datURL() );
         int resNum = thread->resNum();
+        double speed = resNum / (since.secsTo( current ) / (60.0 * 60.0 * 24.0) );
 
         Kita::ThreadListViewItem* item = new Kita::ThreadListViewItem( subjectList );
         item->setText( Col_ID, QString( "%1" ).arg( i + 1, 4 ) );
@@ -158,6 +163,7 @@ void KitaSubjectView::loadBoard( const QString& boardURL )
         item->setText( Col_Board, thread->boardName() );
         item->setText( Col_Since, since.toString( "yy/MM/dd hh:mm" ) );
         item->setText( Col_DatURL, thread->datURL() );
+        item->setText( Col_Speed, QString(" %1 ").arg( speed, 0, 'f', 2 ) );
 
         // FIXME: updateThread˥ԡƤ
         // TODO: 'N'Υ
@@ -199,18 +205,26 @@ void KitaSubjectView::loadBoard( const QString& boardURL )
         break;
     }
 
+    subjectList->setSelected( subjectList->firstChild(), TRUE );
     subjectList->setFocus();
     UpdateKindLabel();
 }
 
-/* public */
-void KitaSubjectView::setFocusList()
+/* public slot */ /* virtual */
+void KitaSubjectView::setFocus()
 {
-    setActiveWindow();
-    topLevelWidget()->raise();
     subjectList->setFocus();
 }
 
+/* public slot */
+void KitaSubjectView::slotFocusSearchCombo()
+{
+    if ( ! SearchCombo->hasFocus() ) {
+        SearchCombo->setFocus();
+    } else {
+	setFocus();
+    }
+}
 
 void KitaSubjectView::UpdateKindLabel()
 {
@@ -331,7 +345,7 @@ void KitaSubjectView::deleteLog( const KURL& url )
                                QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default )
             == QMessageBox::Ok )
     {
-        Kita::DatManager::deleteCache( url, this );
+        Kita::DatManager::deleteCache( url );
 	  emit closeThreadTab( url );
 	  slotUpdateSubject( url );
     }
