@@ -32,9 +32,10 @@ public:
     ~KitaSubjectView();
     const QString boardURL();
     const QString boardName();
-    void setFocusList();
 
 public slots:
+    virtual void setFocus();
+    void slotFocusSearchCombo(); 
     void reloadSubject();
     void loadBoard( const QString& boardURL );
     void setFont( const QFont& font );
