@@ -12,6 +12,7 @@
 #include "thread.h"
 #include "cache.h"
 #include "kita_misc.h"
+#include "account.h"
 
 #include <config.h>
 
@@ -37,14 +38,12 @@ using namespace Kita;
 
 QString Access::getcache()
 {
-    QString cachePath = Kita::Cache::getPath( m_url );
+    QString cachePath = Kita::Cache::getPath( m_datURL );
     m_orgData = QString::null;
 
-    if( cachePath != QString::null )
-    {
+    if ( cachePath != QString::null ) {
         QFile file( cachePath );
-        if ( file.open( IO_ReadOnly ) )
-        {
+        if ( file.open( IO_ReadOnly ) ) {
             m_orgData += file.readAll();
             file.close();
         }
@@ -56,15 +55,14 @@ QString Access::getcache()
 // å˽񤭹ߡ
 void Access::writeCacheData()
 {
-    if ( m_invalidDataReceived ) return;
-    if ( m_threadData == QString::null ) return;
+    if ( m_invalidDataReceived ) return ;
+    if ( m_threadData == QString::null ) return ;
 
     m_orgData += m_threadData;
 
-    QString cachePath = Kita::Cache::getPath( m_url );
-    if( cachePath != QString::null )
-    {
-        FILE *fs = fopen( QFile::encodeName( cachePath ), "w" );
+    QString cachePath = Kita::Cache::getPath( m_datURL );
+    if ( cachePath != QString::null ) {
+        FILE * fs = fopen( QFile::encodeName( cachePath ), "w" );
         if ( !fs ) return ;
 
         fwrite( m_orgData, m_orgData.length(), 1, fs );
@@ -76,9 +74,8 @@ void Access::writeCacheData()
 
 QString Access::getupdate()
 {
-    QString getURL = m_url.url();
-    if ( Kita::boardType( getURL ) == Board_MachiBBS )
-    {
+    QString getURL = m_datURL.url();
+    if ( Kita::boardType( getURL ) == Board_MachiBBS ) {
         getURL = Kita::datToThread( getURL );
     }
 
@@ -87,8 +84,7 @@ QString Access::getupdate()
     m_firstReceive = FALSE;
     m_invalidDataReceived = FALSE;
 
-    if ( KURL( getURL ).protocol() != "k2ch" )
-    {
+    if ( KURL( getURL ).protocol() != "k2ch" ) {
         KIO::SlaveConfig::self() ->setConfigData( "http",
                 KURL( getURL ).host(),
                 "UserAgent",
@@ -104,8 +100,7 @@ QString Access::getupdate()
 
     // use 'HTTP-Headers' metadata.
     job->addMetaData( "PropagateHttpHeader", "true" );
-    if ( ! m_orgData.isNull() )
-    {
+    if ( ! m_orgData.isNull() ) {
         m_firstReceive = TRUE; /* remove first char. see also slotReceiveThreadData() */
         job->addMetaData( "resume", QString::number( m_orgData.length() - 1 ) );
         job->addMetaData( "AllowCompressedPage", "false" );
@@ -123,16 +118,13 @@ void Access::make_cacheDir( const KURL& url )
     KURL cacheDir = KURL( cachePath, "." );
     KURL cacheDir2 = KURL( cacheDir, ".." );
     KURL cacheDir3 = KURL( cacheDir2, ".." );
-    if ( !KIO::NetAccess::exists( cacheDir3 ) )
-    {
+    if ( !KIO::NetAccess::exists( cacheDir3 ) ) {
         KIO::NetAccess::mkdir( cacheDir3 );
     }
-    if ( !KIO::NetAccess::exists( cacheDir2 ) )
-    {
+    if ( !KIO::NetAccess::exists( cacheDir2 ) ) {
         KIO::NetAccess::mkdir( cacheDir2 );
     }
-    if ( !KIO::NetAccess::exists( cacheDir ) )
-    {
+    if ( !KIO::NetAccess::exists( cacheDir ) ) {
         KIO::NetAccess::mkdir( cacheDir );
     }
 }
@@ -140,29 +132,22 @@ void Access::make_cacheDir( const KURL& url )
 void Access::slotThreadResult( KIO::Job* job )
 {
     m_currentJob = 0;
-    if ( job->error() )
-    {
+    if ( job->error() ) {
         job->showErrorDialog();
-    }
-    else
-    {
+    } else {
         m_header = job->queryMetaData( "HTTP-Headers" );
     }
 
-    if ( !m_invalidDataReceived && m_threadData.length() )
-    {
-        if ( Kita::boardType( m_url.url() ) == Board_MachiBBS )
-        {
+    if ( !m_invalidDataReceived && m_threadData.length() ) {
+        if ( Kita::boardType( m_datURL.url() ) == Board_MachiBBS ) {
             // TODO: need to refactoring.
-            parse_machiBBS();
-            KURL url = m_url;
+            m_threadData = Kita::parse_machibbs_dat( m_threadData );
+            KURL url = m_datURL;
             make_cacheDir( url );
             writeCacheData();
             emit receiveData( m_threadData );
-        }
-        else
-        {
-            KURL url = m_url;
+        } else {
+            KURL url = m_datURL;
             make_cacheDir( url );
             writeCacheData();
         }
@@ -170,108 +155,24 @@ void Access::slotThreadResult( KIO::Job* job )
     emit finishLoad();
 }
 
-void Access::parse_machiBBS()
-{
-    QString ret;
-    QStringList lines = QStringList::split( "\n", m_threadData );
-    // pattern 1 (tokyo,kanagawa,...)
-    QRegExp regexp( "<dt>(.*) .*<font color=\"#......\"><b> (.*) </b></font> .* (..../../..).* (..:..:..) ID:(.*)<br><dd>(.*)" );
-    QRegExp regexp2( "<dt>(.*) .*<a href=\"mailto:(.*)\"><b> (.*) </B></a> .* (..../../..).* (..:..:..) ID:(.*)<br><dd>(.*)" );
-
-    // pattern 2 (hokkaido,...)
-    QRegExp regexp3( "<dt>(.*) .*<font color=\"#......\"><b> (.*) </b></font> .* (..../../..).* (..:..:..) ID:(.*)<font size=.>\\[ .*" );
-    QRegExp regexp4( " \\]</font><br><dd>(.*)" );
-    QRegExp regexp5( "<dt>(.*) .*<a href=\"mailto:(.*)\"><b> (.*) </B></a> .* (..../../..).* (..:..:..) ID:(.*)<font size=.>\\[ .*" );
-    for ( QStringList::iterator it = lines.begin(); it != lines.end(); ++it )
-    {
-        QString line = (*it);
-        if ( regexp.search( line ) != -1 )
-        {
-            int num = regexp.cap( 1 ).toInt();
-            QString name = regexp.cap( 2 );
-            QString date = regexp.cap( 3 );
-            QString time = regexp.cap( 4 );
-            QString id = regexp.cap( 5 );
-            QString message = regexp.cap( 6 );
-            QString datStr = name + "<><>" + date + " " + time + " ID:" + id
-                             + "<>" + message + "<>\n";
-            ret += datStr;
-        }
-        else if ( regexp2.search( line ) != -1 )
-        {
-            int num = regexp2.cap( 1 ).toInt();
-            QString mail = regexp2.cap( 2 );
-            QString name = regexp2.cap( 3 );
-            QString date = regexp2.cap( 4 );
-            QString time = regexp2.cap( 5 );
-            QString id = regexp2.cap( 6 );
-            QString message = regexp2.cap( 7 );
-            QString datStr = name + "<>" + mail + "<>" + date + " " + time + " ID:" + id
-                             + "<>" + message + "<>\n";
-            ret += datStr;
-        }
-        else if ( regexp3.search( line ) != -1 )
-        {
-            ++it;
-            if ( it == lines.end() ) break;
-            QString nextLine = (*it);
-            if ( regexp4.search( nextLine ) != -1 )
-            {
-                int num = regexp3.cap( 1 ).toInt();
-                QString name = regexp3.cap( 2 );
-                QString date = regexp3.cap( 3 );
-                QString time = regexp3.cap( 4 );
-                QString id = regexp3.cap( 5 );
-                QString message = regexp4.cap( 1 );
-                QString datStr = name + "<><>" + date + " " + time + " ID:" + id
-                                 + "<>" + message + "<>\n";
-                ret += datStr;
-            }
-        }
-        else if ( regexp5.search( line ) != -1 )
-        {
-            ++it;
-            if ( it == lines.end() ) break;
-            QString nextLine = (*it);
-            if ( regexp4.search( nextLine ) != -1 )
-            {
-                int num = regexp5.cap( 1 ).toInt();
-                QString mail = regexp5.cap( 2 );
-                QString name = regexp5.cap( 3 );
-                QString date = regexp5.cap( 4 );
-                QString time = regexp5.cap( 5 );
-                QString id = regexp5.cap( 6 );
-                QString message = regexp4.cap( 1 );
-                QString datStr = name + "<>" + mail + "<>" + date + " " + time + " ID:" + id
-                                 + "<>" + message + "<>\n";
-                ret += datStr;
-            }
-        }
-    }
-    m_threadData = ret;
-}
-
-
 void Access::slotReceiveThreadData( KIO::Job*, const QByteArray& data )
 {
     QString cstr( data );
 
-    if( ( m_orgData != QString::null && responseCode() != 206 )
-            || ( m_firstReceive && cstr[0] != '\n' )
+    if ( ( m_orgData != QString::null && responseCode() != 206 )
+            || ( m_firstReceive && cstr[ 0 ] != '\n' )
             || ( m_orgData == QString::null && responseCode() != 200 )
-      ) m_invalidDataReceived = TRUE;
+       ) m_invalidDataReceived = TRUE;
 
-    if( m_invalidDataReceived ) return;
+    if ( m_invalidDataReceived ) return ;
 
     /* If this is the first call at resumption, remove LF at head. */
-    if(m_firstReceive)
-    {
-        cstr = cstr.mid(1);
+    if ( m_firstReceive ) {
+        cstr = cstr.mid( 1 );
     }
     m_firstReceive = FALSE;
     m_threadData += cstr ;
-    if ( Kita::boardType( m_url.url() ) != Board_MachiBBS )
-    {
+    if ( Kita::boardType( m_datURL.url() ) != Board_MachiBBS ) {
         emit receiveData( cstr );
     }
 }
@@ -289,18 +190,15 @@ void Access::stopJob()
 
 int Access::serverTime()
 {
-    if(m_currentJob) m_header = m_currentJob->queryMetaData( "HTTP-Headers" );
+    if ( m_currentJob ) m_header = m_currentJob->queryMetaData( "HTTP-Headers" );
     // parse HTTP headers
     QStringList headerList = QStringList::split( "\n", m_header );
     QRegExp regexp( "Date: (...), (..) (...) (....) (..:..:..) .*" );
     QString dateStr = headerList.grep( regexp ) [ 0 ];
-    if ( regexp.search( dateStr ) == -1 )
-    {
+    if ( regexp.search( dateStr ) == -1 ) {
         // invalid date format
         return QDateTime::currentDateTime().toTime_t();
-    }
-    else
-    {
+    } else {
         // I hate this format ;p
         QString usLocalDateStr = regexp.cap( 1 ) + " " + regexp.cap( 3 ) + " " +
                                  regexp.cap( 2 ) + " " + regexp.cap( 5 ) + " " +
@@ -314,27 +212,93 @@ int Access::serverTime()
 
 int Access::responseCode()
 {
-    if(m_currentJob) m_header = m_currentJob->queryMetaData( "HTTP-Headers" );
+    if ( m_currentJob ) m_header = m_currentJob->queryMetaData( "HTTP-Headers" );
     // parse HTTP headers
     QStringList headerList = QStringList::split( "\n", m_header );
     QRegExp regexp( "HTTP/1\\.[01] ([0-9]+) .*" );
     QString dateStr = headerList.grep( regexp ) [ 0 ];
-    if ( regexp.search( dateStr ) == -1 )
-    {
+    if ( regexp.search( dateStr ) == -1 ) {
         // invalid response
         return 0;
-    }
-    else
-    {
+    } else {
         return regexp.cap( 1 ).toInt();
     }
 }
 
-bool Access::deleteLog( const Thread* thread, QWidget* parent )
+bool Access::deleteLog( const Thread* thread )
 {
     KURL url = thread->datURL();
     QString str = Kita::Cache::getPath( url );
     return KIO::NetAccess::del( str );
 }
 
+//
+// access offlaw.cgi
+//
+QString OfflawAccess::get()
+{
+    QString getURL = Kita::datToOfflaw( m_datURL.url() );
+    KURL kgetURL( getURL );
+    kgetURL.addQueryItem( "sid", Account::getSessionID() );
+
+    QString retstr;
+    m_threadData = "";
+    m_invalidDataReceived = FALSE;
+
+    KIO::SlaveConfig::self() ->setConfigData( "http",
+            KURL( getURL ).host(),
+            "UserAgent",
+            QString( "Monazilla/1.00 (Kita/%1)" ).arg( VERSION ) );
+
+    KIO::TransferJob* job = KIO::get( kgetURL, true, false );
+    m_currentJob = job;
+
+    connect( job, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
+             SLOT( slotReceiveThreadData( KIO::Job*, const QByteArray& ) ) );
+    connect( job, SIGNAL( result( KIO::Job* ) ), SLOT( slotThreadResult( KIO::Job* ) ) );
+
+    // use 'HTTP-Headers' metadata.
+    job->addMetaData( "PropagateHttpHeader", "true" );
+
+    return QString::null; /* dummy */
+}
+
+void OfflawAccess::slotThreadResult( KIO::Job* job )
+{
+    m_currentJob = 0;
+    if ( job->error() ) {
+        job->showErrorDialog();
+    } else {
+        m_header = job->queryMetaData( "HTTP-Headers" );
+    }
+
+    if ( !m_invalidDataReceived && m_threadData.length() ) {
+        KURL url = m_datURL;
+        make_cacheDir( url );
+        writeCacheData();
+    }
+    emit finishLoad();
+}
+
+void OfflawAccess::slotReceiveThreadData( KIO::Job*, const QByteArray& data )
+{
+    QString cstr( data );
+
+    if ( ( m_orgData != QString::null && responseCode() != 206 )
+            || ( m_orgData == QString::null && responseCode() != 200 ) ) {
+        m_invalidDataReceived = TRUE;
+    }
+
+    if ( m_invalidDataReceived ) return ;
+
+    // "+OK ....../1024K\tLocation:temp/\n"
+    if ( m_threadData.isEmpty() && cstr[0] == '+' ) {
+        // skip first line.
+        int index = cstr.find( '\n' );
+        cstr = cstr.mid( index + 1 );
+    }
+    m_threadData += cstr ;
+    emit receiveData( cstr );
+}
+
 #include "access.moc"
