@@ -31,8 +31,8 @@ namespace Kita
         Q_OBJECT
 
     public:
-        Access( const KURL& url ) : m_url( url ), m_currentJob( 0 ) {};
-        ~Access() {};
+        Access( const KURL& datURL ) : m_datURL( datURL ), m_currentJob( 0 ) {};
+        virtual ~Access() {};
 
         QString get();
         void killJob();
@@ -41,14 +41,13 @@ namespace Kita
         QString getcache();
         QString getupdate();
         int responseCode();
-        static bool deleteLog( const Thread* thread, QWidget* parent );
+        static bool deleteLog( const Thread* thread );
 
-    private:
+    protected:
         void writeCacheData();
-        void parse_machiBBS();
         void make_cacheDir( const KURL& url );
 
-        const KURL m_url;
+        const KURL m_datURL;
         KIO::Job* m_currentJob;
         QString m_threadData;
         QString m_header;
@@ -66,6 +65,20 @@ namespace Kita
         void finishLoad();
     };
 
+    class OfflawAccess : public Access
+    {
+        Q_OBJECT
+
+    public:
+        OfflawAccess( const KURL& datURL ) : Access( datURL ) {};
+        virtual ~OfflawAccess() {};
+
+        QString get();
+
+    private slots:
+        void slotReceiveThreadData( KIO::Job* job, const QByteArray& data );
+        void slotThreadResult( KIO::Job* job );
+    };
 }
 
 #endif
