@@ -20,9 +20,12 @@
 
 #include <qregexp.h>
 #include <qdict.h>
+#include <qdir.h>
 
 #include "kita_misc.h"
 #include "threadinfo.h"
+#include "cache.h"
+#include "datmanager.h"
 
 #include "qcp932codec.h"
 
@@ -54,6 +57,43 @@ const QPtrList<Thread> Board::getThreadList( const QString& boardURL )
     }
     QPtrList<Thread> threadList;
 
+    /* get all obtained threads list */
+    if( boardURL == "http://virtual/obtained/" ){
+
+	QDictIterator<Kita::Board> it( *m_boardDict );
+	for ( ; it.current(); ++it ) {
+
+	    /* get the cache dir */
+	    QString boardUrl = it.currentKey() + "dat/";
+	    QString cdir = Cache::getPath( boardUrl + "dummy.dat" );
+	    int i = cdir.findRev( "dummy.dat");
+	    cdir.truncate( i );
+	    
+	    /* get the file names */
+	    QDir d( cdir );
+	    if ( d.exists() ){
+		QStringList flist = d.entryList( "*.dat" );
+		for( QStringList::iterator it = flist.begin();  it != flist.end(); ++it ){
+		    if( (*it) == QString::null ) continue;
+
+		    QString datURL = boardUrl + (*it);
+
+		    /* get the name of the thread from the dat file */
+		    QString subject = DatManager::threadName( datURL );  
+
+		    if( subject == QString::null ) Kita::Thread::setName( datURL, "?" );
+		    int rnum = KitaThreadInfo::readNum( datURL );
+		    if( KitaThreadInfo::resNum( datURL ) < rnum ) KitaThreadInfo::setResNum( datURL, rnum  );
+		    Kita::Thread* thread = Kita::Thread::getByURL( datURL );
+		    threadList.append( thread );
+		}
+	    }
+	}
+	
+	return threadList;	
+    }
+    
+
     KIO::SlaveConfig::self() ->setConfigData( "http",
             KURL( boardURL ).host() ,
             "UserAgent",
@@ -63,10 +103,10 @@ const QPtrList<Thread> Board::getThreadList( const QString& boardURL )
         QIODevice * tmpDevice = KFilterDev::deviceForFile( tmpFile, "application/x-gzip" );
         tmpDevice->open( IO_ReadOnly );
 
-        if( !m_cp932Codec ) m_cp932Codec = new QCp932Codec();
-        if( !m_eucJpCodec ) m_eucJpCodec = new QEucJpCodec();
+        if ( !m_cp932Codec ) m_cp932Codec = new QCp932Codec();
+        if ( !m_eucJpCodec ) m_eucJpCodec = new QEucJpCodec();
         QTextStream stream( tmpDevice );
-        
+
         if ( Kita::boardType( boardURL ) == Board_JBBS ) {
             stream.setCodec( m_eucJpCodec );
         } else {
@@ -153,7 +193,11 @@ void Board::setName( const QString& boardURL, const QString& boardName )
 
 const QString& Board::getName( const QString& boardURL )
 {
-    return Board::getByURL( boardURL ) ->m_boardName;
+    if ( m_boardDict->find( boardURL ) ) {
+        return Board::getByURL( boardURL ) ->m_boardName;
+    } else {
+        return QString::null;
+    }
 }
 
 void Board::replace( const QString& fromURL, const QString& toURL )
