@@ -22,9 +22,16 @@ namespace Kita
     */
     class Cache
     {
-        static QString baseDir( const KURL& url );
+        static QString baseDir();
+	static QString subDir( const KURL& url );
+	static QString hashString( const KURL& url );
+	static QString getImgBaseDir();
+	static QString getImgFileName( const KURL& src);
+
     public:
         static QString getPath( const KURL& url );
+	static QString getImgPath( const KURL& url);
+	static QString getImgIdxPath( const KURL& url);	
     };
 
 }
