@@ -1,6 +1,6 @@
 /**************************************************************************
 *   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
-*   ikemo@wakaba.jp                                                       *
+*   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -13,6 +13,7 @@
 #include <klocale.h>
 #include <dom/html_document.h>
 #include <dom/html_element.h>
+#include <dom/html_table.h>
 #include <dom/dom_text.h>
 
 #include "datinfo.h"
@@ -25,19 +26,22 @@
 #include "kita-utf8.h"
 #include "kita-utf16.h"
 #include "kita_misc.h"
+#include "account.h"
+
 
 using namespace Kita;
 
-#define KITA_MAXRES 1200
+#define RESDAT_DEFAULTSIZE 10
+#define RESDAT_DELTA       1000
 
 
 /*------------------------------------------------------*/
 /* DatInfo stores & handles all information about *.dat */
 
-DatInfo::DatInfo( const KURL& url ) : m_access ( 0 )
+DatInfo::DatInfo( const KURL& url ) : m_access ( 0 ), m_access2( 0 )
 {
     QString refstr;
-    m_datURL = Kita::ParseMisc::parseURL( url, refstr);
+    m_datURL = Kita::ParseMisc::parseURL( url, refstr );
     m_thread = Kita::Thread::getByURLNew( m_datURL );
 
     /* japanese strings */
@@ -81,11 +85,9 @@ void DatInfo::initPrivate()
     m_lastLine = QString::null;
     m_kokoyonNum = KitaThreadInfo::readNum( m_datURL.prettyURL() );
 
-    /* clear & resize ResDatVec */
-    RESDAT resdat;
-    resetResDat(resdat);
+    /* clear ResDatVec */
     m_resDatVec.clear();
-    m_resDatVec.resize(KITA_MAXRES,resdat);
+    increaseResDatVec( RESDAT_DEFAULTSIZE );
 
     /* reset Abone */
     resetAbonePrivate();
@@ -95,16 +97,16 @@ void DatInfo::initPrivate()
 
     connect( m_access, SIGNAL( receiveData( const QString& ) ),
              SLOT( slotReceiveData( const QString& ) ) );
-    connect( m_access, SIGNAL( finishLoad() ),SLOT( slotFinishLoad() ) );
+    connect( m_access, SIGNAL( finishLoad() ), SLOT( slotFinishLoad() ) );
 
     /* get dat from cahce & copy it to buffer */
-    copyRawDataToBuffer(m_access->getcache());
-    copyRawDataToBuffer(QString::null); /* copy the last line */
+    copyRawDataToBuffer( m_access->getcache() );
+    copyRawDataToBuffer( QString::null ); /* copy the last line */
 }
 
 
 /* private */
-void DatInfo::resetResDat(RESDAT& resdat)
+void DatInfo::resetResDat( RESDAT& resdat )
 {
 
     resdat.set = FALSE;
@@ -118,16 +120,29 @@ void DatInfo::resetResDat(RESDAT& resdat)
 }
 
 
+/* private */
+void DatInfo::increaseResDatVec( int delta )
+{
+    int size = m_resDatVec.size();
+    RESDAT resdat;
+    resetResDat( resdat );
+    m_resDatVec.resize( size + delta, resdat );
+}
+
 
 /* delete dat loader */ /* private */
 void DatInfo::deleteAccessJob()
 {
-    if ( m_access )
-    {
+    if ( m_access ) {
         m_access->killJob();
         delete m_access;
         m_access = NULL;
     }
+    if ( m_access2 ) {
+        m_access2->killJob();
+        delete m_access2;
+        m_access2 = NULL;
+    }
 }
 
 /* copy raw lines to buffer */
@@ -136,23 +151,21 @@ void DatInfo::deleteAccessJob()
    You need to call this function last
    with rawData = QString::null in order
    to copy the last line to buffer.      */ /* private */
-void DatInfo::copyRawDataToBuffer(const QString& rawData)
+void DatInfo::copyRawDataToBuffer( const QString& rawData )
 {
     QStringList linelist;
     int basenum = m_readNum + 1;
 
     // hack for machiBBS
-    if ( Kita::boardType( m_datURL.url() ) == Board_MachiBBS && m_lastLine == QString::null && m_access->responseCode() == 200 )
-    {
+    if ( Kita::boardType( m_datURL.url() ) == Board_MachiBBS && m_lastLine == QString::null && m_access->responseCode() == 200 ) {
         basenum = 1;
         m_readNum = 0;
     }
 
     bool endIsLF = FALSE;
-    if ( rawData != QString::null )
-    {
+    if ( rawData != QString::null ) {
 
-        if(rawData.at(rawData.length()-1) == '\n') endIsLF = TRUE;
+        if ( rawData.at( rawData.length() - 1 ) == '\n' ) endIsLF = TRUE;
 
         /* split the raw data */
         m_lastLine += rawData;
@@ -161,28 +174,23 @@ void DatInfo::copyRawDataToBuffer(const QString& rawData)
         /* backup the last line */
         QStringList::iterator lastit = linelist.end();
         lastit--;
-        if( lastit != linelist.end() )
-        {
-            m_lastLine = (*lastit);
-            linelist.remove(lastit);
+        if ( lastit != linelist.end() ) {
+            m_lastLine = ( *lastit );
+            linelist.remove( lastit );
 
             /* If the last char of rawData is LF, then
                add LF to m_lastLine, because LF was
                removed by above QStringList::split().  */
-            if(endIsLF) m_lastLine += '\n';
-        }
-        else m_lastLine = QString::null;
+            if ( endIsLF ) m_lastLine += '\n';
+        } else m_lastLine = QString::null;
 
-    }
-    else
-    { /* If rawData == null, then copy the last line */
+    } else { /* If rawData == null, then copy the last line */
 
         if ( m_lastLine != QString::null
                 && m_lastLine.contains( "<>" ) == 4
-                && m_lastLine.at(m_lastLine.length()-1) == '\n' )
-        {
+                && m_lastLine.at( m_lastLine.length() - 1 ) == '\n' ) {
 
-            m_lastLine.truncate(m_lastLine.length()-1);/* remove LF */
+            m_lastLine.truncate( m_lastLine.length() - 1 ); /* remove LF */
             linelist += m_lastLine;
             m_lastLine = QString::null;
         }
@@ -190,48 +198,57 @@ void DatInfo::copyRawDataToBuffer(const QString& rawData)
 
     /* copy lines to buffer */
     for ( QStringList::iterator it = linelist.begin();
-            it != linelist.end(); ++it, ++basenum )
-    {
-        if((*it) != QString::null)
-        {
-            QString line = ParseMisc::qcpToUnicode((*it));
-            setDat(line,basenum);
+            it != linelist.end(); ++it, ++basenum ) {
+        if ( ( *it ) != QString::null ) {
+            QString line = ParseMisc::qcpToUnicode( ( *it ) );
+            copyOneLineToResDat( line, basenum );
         }
     }
 
+    updateThreadInfo();
+}
+
+void DatInfo::updateThreadInfo()
+{
     /* update thread info */
     if ( !m_thread && m_readNum ) {
         m_thread = Kita::Thread::getByURL( m_datURL.prettyURL() );
     }
-    if( m_thread ){
-	if( m_thread->resNum() < m_readNum ) m_thread->setResNum( m_readNum );
-	KitaThreadInfo::setReadNum( m_datURL.prettyURL(), m_readNum );
+    if ( m_thread ) {
+        if ( m_thread->resNum() < m_readNum ) {
+            KitaThreadInfo::setResNum( m_datURL.prettyURL(), m_readNum );
+        }
+        KitaThreadInfo::setReadNum( m_datURL.prettyURL(), m_readNum );
     }
 }
 
 
 
-/* private */
-bool DatInfo::setDat( const QString& line, int num )
+/* copy one line to resdat.            */
+/* This private function is called in
+   copyRawDataToBuffer.                */ /* private */
+bool DatInfo::copyOneLineToResDat( const QString& line, int num )
 {
 
-    if ( num <= 0 || (int) m_resDatVec.size() <= num ) return FALSE;
+    if ( num <= 0 ) return FALSE;
     if ( line == QString::null ) return FALSE;
 
+    /* If resdat vector is short, then resize the vector. */
+    while ( ( int ) m_resDatVec.size() <= num ) increaseResDatVec( RESDAT_DELTA );
+
     /* reset and  set new data */
     RESDAT& resdat = m_resDatVec[ num ];
-    resetResDat(resdat);
+    resetResDat( resdat );
 
     resdat.set = TRUE;
     resdat.linestr = line;
-    if(m_readNum < num) m_readNum = num;
+    if ( m_readNum < num ) m_readNum = num;
     m_rawData += line + '\n';
 
-    if(num == 1) parseDat ( num ); /* to get subject */
+    if ( num == 1 ) parseDat ( num ); /* to get subject */
 
     /* is this dat file broken ? */
-    if ( line.contains( "<>" ) != 4 )
-    {
+    if ( line.contains( "<>" ) != 4 ) {
         resdat.broken = TRUE;
         m_broken = TRUE;
     }
@@ -262,7 +279,7 @@ const KURL& DatInfo::url()
 /* When Kita::Access fineshed loading,
    slotFinishLoad is called, and
    DatInfo emits the finishLoad signal to the parent object  */ /* public */
-bool DatInfo::updateCache(const QObject* parent)
+bool DatInfo::updateCache( const QObject* parent )
 {
     QMutexLocker locker( &m_mutex );
     if ( m_access == NULL ) return FALSE;
@@ -272,10 +289,10 @@ bool DatInfo::updateCache(const QObject* parent)
     m_lock++; /* By locking, DatManager can't delete this while loading. */
 
     connect( this, SIGNAL( receiveData() ),
-             parent,SLOT( slotReceiveData() ) );
+             parent, SLOT( slotReceiveData() ) );
 
     connect( this, SIGNAL( finishLoad() ),
-             parent,SLOT( slotFinishLoad() ) );
+             parent, SLOT( slotFinishLoad() ) );
 
     m_access->getupdate();
 
@@ -285,14 +302,16 @@ bool DatInfo::updateCache(const QObject* parent)
 
 /* slot called when Kita::Access
    received new data              */      /* private  slot */
-void DatInfo::slotReceiveData(const QString& newLine)
+void DatInfo::slotReceiveData( const QString& newLine )
 {
-
     int rescode = m_access->responseCode();
+    if ( m_access2 ) {
+        rescode = m_access2->responseCode();
+    }
 
-    if(rescode != 200 && rescode != 206) return;
+    if ( rescode != 200 && rescode != 206 ) return ;
 
-    copyRawDataToBuffer(newLine);
+    copyRawDataToBuffer( newLine );
 
     emit receiveData();
 }
@@ -304,17 +323,28 @@ void DatInfo::slotFinishLoad()
 {
 
     /* copy the last line */
-    copyRawDataToBuffer(QString::null);
+    copyRawDataToBuffer( QString::null );
 
+    if ( m_readNum == 0 && m_access2 == NULL && Kita::is2ch( m_datURL ) ) {
+        if ( Account::isLogged() ) {
+            initPrivate();
+            m_access2 = new OfflawAccess( m_datURL );
+            connect( m_access2, SIGNAL( receiveData( const QString& ) ),
+                      SLOT( slotReceiveData( const QString& ) ) );
+            connect( m_access2, SIGNAL( finishLoad() ), SLOT( slotFinishLoad() ) );
+            m_access2->get();
+            return;
+        }
+    }
     /* finish loading session & emit signal to the parent object */
     m_nowLoading = FALSE;
     emit finishLoad();
 
     /* disconnect signals */
-    disconnect( SIGNAL( receiveData() ));
+    disconnect( SIGNAL( receiveData() ) );
     disconnect( SIGNAL( finishLoad() ) );
 
-    if(m_lock) m_lock--;
+    if ( m_lock ) m_lock--;
 }
 
 
@@ -339,16 +369,16 @@ int DatInfo::getServerTime()
 
 
 /* public */
-bool DatInfo::deleteCache(QWidget* parent)
+bool DatInfo::deleteCache()
 {
     QMutexLocker locker( &m_mutex );
     if ( m_access == NULL ) return FALSE;
     if ( m_nowLoading ) return FALSE;
 
     bool ret = FALSE;
-    if( m_thread ) ret = Kita::Access::deleteLog( m_thread, parent );
+    if ( m_thread ) ret = Kita::Access::deleteLog( m_thread );
     KitaThreadInfo::removeThreadInfo( m_datURL.prettyURL() );
-    if(ret) initPrivate();
+    if ( ret ) initPrivate();
 
     return ret;
 }
@@ -373,8 +403,8 @@ void DatInfo::stopLoading()
        It will cause deadlock , because
        Kita::Access::stopJob() calls KitaThreadView::slotFinishLoad() back,
        then slotFinishLoad calls another functions in DatInfo. */
-    if ( m_access == NULL ) return;
-    if (! m_nowLoading ) return;
+    if ( m_access == NULL ) return ;
+    if ( ! m_nowLoading ) return ;
 
     m_access->stopJob();
 }
@@ -390,7 +420,7 @@ void DatInfo::stopLoading()
 
 /* They are public */
 
-void DatInfo::lock()
+void DatInfo::lock ()
 {
     QMutexLocker locker( &m_mutex );
 
@@ -401,7 +431,7 @@ void DatInfo::unlock()
 {
     QMutexLocker locker( &m_mutex );
 
-    if(m_lock) m_lock--;
+    if ( m_lock ) m_lock--;
 }
 
 int DatInfo::isLocked()
@@ -435,7 +465,7 @@ const QString& DatInfo::getDat( int num )
 {
     QMutexLocker locker( &m_mutex );
 
-    if ( num <= 0 || KITA_MAXRES <= num ) return QString::null;
+    if ( num <= 0 || ( int ) m_resDatVec.size() <= num ) return QString::null;
     if ( ! m_resDatVec[ num ].set ) return QString::null;
 
     return m_resDatVec[ num ].linestr;
@@ -444,7 +474,7 @@ const QString& DatInfo::getDat( int num )
 const QString& DatInfo::getId( int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return QString::null;
+    if ( !parseDat( num ) ) return QString::null;
 
     return m_resDatVec[ num ].id;
 }
@@ -452,7 +482,7 @@ const QString& DatInfo::getId( int num )
 const QString& DatInfo::getBody( int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return QString::null;
+    if ( !parseDat( num ) ) return QString::null;
 
     return m_resDatVec[ num ].body;
 }
@@ -460,7 +490,7 @@ const QString& DatInfo::getBody( int num )
 const QString& DatInfo::getName( int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return QString::null;
+    if ( !parseDat( num ) ) return QString::null;
 
     return m_resDatVec[ num ].name;
 }
@@ -469,36 +499,36 @@ const QString& DatInfo::getName( int num )
 QString DatInfo::getPlainName( int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return QString::null;
+    if ( !parseDat( num ) ) return QString::null;
 
     return m_resDatVec[ num ].parsedName;
 }
 
 
 /* plain (parsed) strings of body  */
-QString DatInfo::getPlainBody(int num)
+QString DatInfo::getPlainBody( int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return QString::null;
+    if ( !parseDat( num ) ) return QString::null;
 
     QString bodytext;
     QString line = m_resDatVec[ num ].body;
 
-    ParseMisc::parseBODYdatText(PARSEMODE_TEXT,line,bodytext);
+    ParseMisc::parseBODYdatText( PARSEMODE_TEXT, line, bodytext );
 
     return bodytext;
 }
 
 
 /* plain (parsed) strings of title */
-QString DatInfo::getPlainTitle(int num)
+QString DatInfo::getPlainTitle( int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return QString::null;
+    if ( !parseDat( num ) ) return QString::null;
 
     bool showAddr = KitaConfig::showMailAddress();
     QString titletext;
-    ParseMisc::parseTITLEdatText(PARSEMODE_TEXT,num,showAddr,m_resDatVec[ num ],titletext);
+    ParseMisc::parseTITLEdatText( PARSEMODE_TEXT, num, showAddr, m_resDatVec[ num ], titletext );
 
     return titletext;
 }
@@ -509,20 +539,19 @@ QString DatInfo::getPlainTitle(int num)
 
 /* HTML strings */
 /* Note that this function checks Abone internally. */ /* public */
-QString DatInfo::getHtml(int startnum, int endnum)
+QString DatInfo::getHtml( int startnum, int endnum )
 {
     QMutexLocker locker( &m_mutex );
 
     QString retstr = QString::null;
     bool showAddr = KitaConfig::showMailAddress();
 
-    for(int num = startnum; num <= endnum; num++)
-    {
+    for ( int num = startnum; num <= endnum; num++ ) {
 
-        if(!parseDat(num)) continue;
-        if(checkAbonePrivate(num)) retstr += aboneHTML( num );
-        else if(m_resDatVec[ num ].broken) retstr += brokenHTML( num );
-        else retstr += ParseMisc::ResDatToHtml(m_resDatVec[ num ],  num, showAddr );
+        if ( !parseDat( num ) ) continue;
+        if ( checkAbonePrivate( num ) ) retstr += aboneHTML( num );
+        else if ( m_resDatVec[ num ].broken ) retstr += brokenHTML( num );
+        else retstr += ParseMisc::ResDatToHtml( m_resDatVec[ num ], num, showAddr );
     }
 
     return retstr;
@@ -531,7 +560,7 @@ QString DatInfo::getHtml(int startnum, int endnum)
 
 /* return HTML strings that have ID = strid. */
 /* Note that this function checks Abone internally. */ /* public */
-QString DatInfo::getHtmlByID(const QString& strid, int &count )
+QString DatInfo::getHtmlByID( const QString& strid, int &count )
 {
     QMutexLocker locker( &m_mutex );
 
@@ -540,17 +569,15 @@ QString DatInfo::getHtmlByID(const QString& strid, int &count )
 
     count = 0;
 
-    for ( int i = 1; i <= m_readNum; i++ )
-    {
+    for ( int i = 1; i <= m_readNum; i++ ) {
 
-        if(!parseDat(i)) continue;
+        if ( !parseDat( i ) ) continue;
 
-        if(m_resDatVec[i].id == strid)
-        {
+        if ( m_resDatVec[ i ].id == strid ) {
             count ++;
-            if(checkAbonePrivate(i)) retstr += aboneHTML(i);
-            else if(m_resDatVec[ i ].broken) retstr += brokenHTML(i);
-            else retstr += ParseMisc::ResDatToHtml(m_resDatVec[i], i, showAddr);
+            if ( checkAbonePrivate( i ) ) retstr += aboneHTML( i );
+            else if ( m_resDatVec[ i ].broken ) retstr += brokenHTML( i );
+            else retstr += ParseMisc::ResDatToHtml( m_resDatVec[ i ], i, showAddr );
         }
     }
 
@@ -559,11 +586,11 @@ QString DatInfo::getHtmlByID(const QString& strid, int &count )
 
 
 /* private */
-QString DatInfo::aboneHTML(int num)
+QString DatInfo::aboneHTML( int num )
 {
 
     QString tmpstr = QString( "<dl><dt>" );
-    tmpstr += QString().setNum( num ) + " "  + ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );
+    tmpstr += QString().setNum( num ) + " " + ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );
     tmpstr += "</dt><dd>";
     tmpstr += ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );;
     tmpstr += "<br/><br/></dd></dl>";
@@ -573,11 +600,11 @@ QString DatInfo::aboneHTML(int num)
 
 
 /* private */
-QString DatInfo::brokenHTML(int num)
+QString DatInfo::brokenHTML( int num )
 {
 
     QString tmpstr = QString( "<dl><dt>" );
-    tmpstr += QString().setNum( num ) + " "  + ParseMisc::utf8ToUnicode( KITAUTF8_NAME );
+    tmpstr += QString().setNum( num ) + " " + ParseMisc::utf8ToUnicode( KITAUTF8_NAME );
     tmpstr += "</dt><dd>";
     tmpstr += ParseMisc::utf8ToUnicode( KITAUTF8_KOWARE );;
     tmpstr += "<br/><br/></dd></dl>";
@@ -597,10 +624,10 @@ QString DatInfo::brokenHTML(int num)
 |-->>20, and return count = 3.  */
 
 /* Note that this function checks Abone internally. */ /* public */
-QString DatInfo::getTreeByRes(const int rootnum, int& count)
+QString DatInfo::getTreeByRes( const int rootnum, int& count )
 {
     QMutexLocker locker( &m_mutex );
-    return getTreeByResPrivate(rootnum,FALSE,count);
+    return getTreeByResPrivate( rootnum, FALSE, count );
 }
 
 /*---------------------------------------*/
@@ -614,24 +641,24 @@ QString DatInfo::getTreeByRes(const int rootnum, int& count)
 |-->>6, and returns count = 3.  */
 
 /* Note that this function checks Abone internally. */ /* public */
-QString DatInfo::getTreeByResReverse(const int rootnum, int& count)
+QString DatInfo::getTreeByResReverse( const int rootnum, int& count )
 {
     QMutexLocker locker( &m_mutex );
-    return getTreeByResPrivate(rootnum,TRUE,count);
+    return getTreeByResPrivate( rootnum, TRUE, count );
 }
 
 
 /* private */
 QString DatInfo::getTreeByResPrivate(
     const int rootnum,
-    bool reverse,  /* reverse search */
-    int& count)
+    bool reverse,   /* reverse search */
+    int& count )
 {
 
     QString tmp = QString().setNum( rootnum );
     QString retstr = "<a href=\"#" + tmp + "\">&gt;&gt;" + tmp + "</a><br>";
 
-    retstr += getTreeByResCore(rootnum,reverse,count,"");
+    retstr += getTreeByResCore( rootnum, reverse, count, "" );
 
     return retstr;
 }
@@ -639,41 +666,34 @@ QString DatInfo::getTreeByResPrivate(
 /* private */
 QString DatInfo::getTreeByResCore(
     const int rootnum,
-    bool reverse,  /* reverse search */
-    int& count, QString prestr)
+    bool reverse,   /* reverse search */
+    int& count, QString prestr )
 {
-    if(!parseDat(rootnum)) return QString::null;
-    if( checkAbonePrivate(rootnum) ) return QString::null;
+    if ( !parseDat( rootnum ) ) return QString::null;
+    if ( checkAbonePrivate( rootnum ) ) return QString::null;
 
     QString retstr = QString::null ;
     count = 0;
     QStringList strlists;
 
-    if( !reverse )
-    {
+    if ( !reverse ) {
 
         /* collect responses that have anchor to rootnum */
-        for ( int i = rootnum+1; i <= m_readNum; i++ )
-        {
-            if(checkAbonePrivate( i ) ) continue;
-            if(checkRes(i,rootnum))
-            {
+        for ( int i = rootnum + 1; i <= m_readNum; i++ ) {
+            if ( checkAbonePrivate( i ) ) continue;
+            if ( checkRes( i, rootnum ) ) {
                 count ++;
                 strlists += QString().setNum( i );
             }
         }
 
-    }
-    else
-    { /* collect responses for which rootnum has anchors */
+    } else { /* collect responses for which rootnum has anchors */
 
-        setAncList(rootnum);
+        setAncList( rootnum );
         AncList& anclist = m_resDatVec[ rootnum ].anclist;
-        for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it )
-        {
-            for( int i = (*it).from; i <= QMIN(rootnum-1,(*it).to) ; i++)
-            {
-                if(checkAbonePrivate(i) ) continue;
+        for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it ) {
+            for ( int i = ( *it ).from; i <= QMIN( rootnum - 1, ( *it ).to ) ; i++ ) {
+                if ( checkAbonePrivate( i ) ) continue;
                 count ++;
                 strlists += QString().setNum( i );
             }
@@ -681,23 +701,21 @@ QString DatInfo::getTreeByResCore(
     }
 
     /* make HTML document */
-    if(count)
-    {
+    if ( count ) {
 
-        for ( QStringList::iterator it = strlists.begin(); it != strlists.end(); ++it )
-        {
+        for ( QStringList::iterator it = strlists.begin(); it != strlists.end(); ++it ) {
             QString tmpstr;
-            if((*it) == strlists.last()) tmpstr = m_framestr3;  /* 'L' */
+            if ( ( *it ) == strlists.last() ) tmpstr = m_framestr3;  /* 'L' */
             else tmpstr = m_framestr2;  /* '|-' */
 
-            retstr += prestr + tmpstr + "<a href=\"#" + (*it) + "\">&gt;&gt;" + (*it) + "</a><br>";
+            retstr += prestr + tmpstr + "<a href=\"#" + ( *it ) + "\">&gt;&gt;" + ( *it ) + "</a><br>";
 
             /* call myself recursively */
             int tmpnum;
             tmpstr = prestr;
-            if((*it) == strlists.last()) tmpstr += m_spacestr + m_spacestr + m_spacestr; /* "   " */
-            else tmpstr += m_framestr1  + m_spacestr; /* "| " */
-            retstr += getTreeByResCore((*it).toInt(),reverse,tmpnum,tmpstr);
+            if ( ( *it ) == strlists.last() ) tmpstr += m_spacestr + m_spacestr + m_spacestr; /* "   " */
+            else tmpstr += m_framestr1 + m_spacestr; /* "| " */
+            retstr += getTreeByResCore( ( *it ).toInt(), reverse, tmpnum, tmpstr );
             count += tmpnum;
         }
     }
@@ -712,16 +730,15 @@ QString DatInfo::getTreeByResCore(
 /* For exsample, if target = 4, and No.num have
    an anchor >>4, or >>2-6, etc.,
    then return TRUE.                            */  /* private */
-bool DatInfo::checkRes(const int num, const int target )
+bool DatInfo::checkRes( const int num, const int target )
 {
-    if(! parseDat(num)) return FALSE;
+    if ( ! parseDat( num ) ) return FALSE;
 
-    setAncList(num);
+    setAncList( num );
     AncList& anclist = m_resDatVec[ num ].anclist;
 
-    for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it )
-    {
-        if ( target >= (*it).from && target <= (*it).to ) return TRUE;
+    for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it ) {
+        if ( target >= ( *it ).from && target <= ( *it ).to ) return TRUE;
     }
 
     return FALSE;
@@ -740,16 +757,16 @@ bool DatInfo::checkRes(const int num, const int target )
    anclist[1].from = 4,
    anclist[1].to = 4.   
 */
-void DatInfo::setAncList(int num)
+void DatInfo::setAncList( int num )
 {
 
-    if(! parseDat(num)) return;
-    if( m_resDatVec[ num ].setAnclist ) return;
+    if ( ! parseDat( num ) ) return ;
+    if ( m_resDatVec[ num ].setAnclist ) return ;
 
     m_resDatVec[ num ].setAnclist = TRUE;
 
     QString linkstr;
-    int refNum[2];
+    int refNum[ 2 ];
     unsigned int pos;
     ANCNUM anctmp;
 
@@ -760,30 +777,27 @@ void DatInfo::setAncList(int num)
 
     /* remove HTML tags */
     QRegExp rex( "<[^>]*>" );
-    line.remove(rex);
+    line.remove( rex );
 
     const QChar *chpt = line.unicode();
     unsigned int i;
     unsigned int length = line.length();
 
     /* parse body */
-    for ( i = 0 ; i < length ; i++ )
-    {
+    for ( i = 0 ; i < length ; i++ ) {
 
-        if( chpt[ i ].unicode() == UTF16_BRACKET || /* > */
-                (chpt[ i] == '&' && chpt[ i+1] == 'g' && chpt[ i+2] == 't' && chpt[ i+3] == ';') /* "&gt;" */
-          )
-        {
-            while(ParseMisc::parseResAnchor(chpt+i,length-i,linkstr,refNum,pos))
-            {
-                if(refNum[1] < refNum[0]) refNum[1] = refNum[0];
-                anctmp.from = refNum[0];
-                anctmp.to = refNum[1];
+        if ( chpt[ i ].unicode() == UTF16_BRACKET ||  /* > */
+                ( chpt[ i ] == '&' && chpt[ i + 1 ] == 'g' && chpt[ i + 2 ] == 't' && chpt[ i + 3 ] == ';' )  /* "&gt;" */
+           ) {
+            while ( ParseMisc::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
+                if ( refNum[ 1 ] < refNum[ 0 ] ) refNum[ 1 ] = refNum[ 0 ];
+                anctmp.from = refNum[ 0 ];
+                anctmp.to = refNum[ 1 ];
                 anclist += anctmp;
                 i += pos;
             }
 
-            i += (pos-1);
+            i += ( pos - 1 );
         }
     }
 
@@ -793,11 +807,10 @@ void DatInfo::setAncList(int num)
     i = 0;
     length = line.length();
 
-    while(ParseMisc::parseResAnchor(chpt+i,length-i,linkstr,refNum,pos))
-    {
-        if(refNum[1] < refNum[0]) refNum[1] = refNum[0];
-        anctmp.from = refNum[0];
-        anctmp.to = refNum[1];
+    while ( ParseMisc::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
+        if ( refNum[ 1 ] < refNum[ 0 ] ) refNum[ 1 ] = refNum[ 0 ];
+        anctmp.from = refNum[ 0 ];
+        anctmp.to = refNum[ 1 ];
         anclist += anctmp;
         i += pos;
     }
@@ -817,43 +830,44 @@ void DatInfo::setAncList(int num)
    
    If the res is broken, the output
    is "broken" node.
-                                    */
+                                    */ 
 /* public */
 bool DatInfo::getDomElement(
 
     /* input */
     int num,
-    DOM::HTMLDocument& hdoc, /* root of HTML document */
+    DOM::HTMLDocument& hdoc,  /* root of HTML document */
 
     /* output */
-    DOM::Element& retelm)
+    DOM::Element& retelm )
 {
 
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return FALSE;
+    if ( !parseDat( num ) ) return FALSE;
 
     QString tmpstr;
     QString status = "normal";
     DOM::Element bodynode, titlenode, tmpelm;
+    DOM::HTMLTableElement table;
     bool showAddr = KitaConfig::showMailAddress();
     bool showAA = KitaConfig::showAA();
     bool abone = checkAbonePrivate( num );
 
     RESDAT& resdat = m_resDatVec[ num ];
 
-    if ( !resdat.broken && !abone )
-    {
+    if ( !resdat.broken && !abone ) {
 
         /* title node */
-        titlenode = hdoc.createElement( "DT" );
-        ParseMisc::parseTITLEdat(PARSEMODE_DOM,hdoc,num,showAddr,resdat,titlenode,tmpstr);
+        table = hdoc.createElement( "TABLE" );
+        titlenode = table;
+        tmpelm = table.insertRow( 0 );
+        ParseMisc::parseTITLEdat( PARSEMODE_DOM, hdoc, num, showAddr, resdat, tmpelm, tmpstr );
 
         /* body node */
-        bodynode = hdoc.createElement( "DD" );
+        bodynode = hdoc.createElement( "DIV" );
         {
             /* put the span node at the head of each line */
-            if ( showAA )
-            {
+            if ( showAA ) {
 
                 tmpelm = bodynode.appendChild( hdoc.createElement( "SPAN" ) );
                 {
@@ -862,36 +876,34 @@ bool DatInfo::getDomElement(
                 }
             }
 
-            ParseMisc::parseBODYdat(PARSEMODE_DOM,resdat.body,hdoc,showAA,bodynode,tmpstr);
+            ParseMisc::parseBODYdat( PARSEMODE_DOM, resdat.body, hdoc, showAA, bodynode, tmpstr );
         }
 
-    }
-    else
-    { /* abone or data is broken */
+    } else { /* abone or data is broken */
 
         QString namestr;
         QString bodystr;
 
-        if(abone)
-        { /* "abone" node */
+        if ( abone ) { /* "abone" node */
             namestr = ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );
             bodystr = ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );
             status = "abone";
-        }
-        else
-        { /* "broken" node */
+        } else { /* "broken" node */
             namestr = ParseMisc::utf8ToUnicode( KITAUTF8_NAME );
             bodystr = ParseMisc::utf8ToUnicode( KITAUTF8_KOWARE );
             status = "broken";
         }
 
         /* title node */
-        titlenode = hdoc.createElement( "DT" );
-        titlenode.appendChild( hdoc.createTextNode(
-                                   QString().setNum( num ) + " " + namestr ) );
+        table = hdoc.createElement( "TABLE" );
+        titlenode = table;
+        tmpelm = table.insertRow( 0 );
+        tmpelm = tmpelm.appendChild( hdoc.createElement( "TD" ) );
+        tmpelm.appendChild( hdoc.createTextNode(
+                                QString().setNum( num ) + " " + namestr ) );
 
         /* body node */
-        bodynode = hdoc.createElement( "DD" );
+        bodynode = hdoc.createElement( "DIV" );
         tmpelm = bodynode.appendChild( hdoc.createElement( "SPAN" ) );
         {
             tmpelm.setAttribute( "style", "color: red" );
@@ -900,12 +912,11 @@ bool DatInfo::getDomElement(
 
     }
 
-    bodynode.appendChild( hdoc.createElement( "BR" ) );
-    bodynode.appendChild( hdoc.createElement( "BR" ) );
 
     /*-----------------------------*/
 
     retelm = hdoc.createElement( "DIV" );
+    retelm.setAttribute( "class", "res_block" );
     {
         retelm.setAttribute( "kita_type", "res" );
         retelm.setAttribute( "kita_status", status );
@@ -913,11 +924,10 @@ bool DatInfo::getDomElement(
         retelm.setAttribute( "kita_rname", resdat.name );
         retelm.setAttribute( "kita_rid", resdat.id );
 
-        tmpelm = retelm.appendChild( hdoc.createElement( "DL" ) );
-        {
-            tmpelm.appendChild( titlenode );
-            tmpelm.appendChild( bodynode );
-        }
+        titlenode.setAttribute( "class", "res_title" );
+        bodynode.setAttribute( "class", "res_body" );
+        retelm.appendChild( titlenode );
+        retelm.appendChild( bodynode );
     }
 
     return TRUE;
@@ -945,13 +955,12 @@ int DatInfo::getNumByID( const QString& strid )
 
     int count = 0;
 
-    for ( int i = 1; i <= m_readNum; i++ )
-    {
+    for ( int i = 1; i <= m_readNum; i++ ) {
 
-        if( !parseDat(i) ) continue;
-        if( checkAbonePrivate( i ) ) continue;
+        if ( !parseDat( i ) ) continue;
+        if ( checkAbonePrivate( i ) ) continue;
 
-        if ( m_resDatVec[i].id == strid ) count++;
+        if ( m_resDatVec[ i ].id == strid ) count++;
     }
 
     return count;
@@ -962,15 +971,15 @@ int DatInfo::getKokoyonNum()
 {
     QMutexLocker locker( &m_mutex );
 
-    return QMIN(m_kokoyonNum, m_readNum);
+    return QMIN( m_kokoyonNum, m_readNum );
 }
 
 /* public */
-void DatInfo::setKokoyonNum(int num)
+void DatInfo::setKokoyonNum( int num )
 {
     QMutexLocker locker( &m_mutex );
 
-    num = QMIN(num, m_readNum);
+    num = QMIN( num, m_readNum );
 
     m_kokoyonNum = num;
     KitaThreadInfo::setReadNum( m_datURL.prettyURL(), num );
@@ -986,11 +995,11 @@ int DatInfo::getDatSize()
 
 
 /* public */
-bool DatInfo::isResValid(int num)
+bool DatInfo::isResValid( int num )
 {
     QMutexLocker locker( &m_mutex );
 
-    return parseDat(num);
+    return parseDat( num );
 }
 
 /* public */
@@ -1002,52 +1011,47 @@ bool DatInfo::isBroken()
 }
 
 /* public */
-bool DatInfo::isResBroken(int num)
+bool DatInfo::isResBroken( int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return FALSE;
+    if ( !parseDat( num ) ) return FALSE;
 
     return m_resDatVec[ num ].broken;
 }
 
 /* ID = strid ? */ /* public */
-bool DatInfo::checkID(const QString& strid, int num )
+bool DatInfo::checkID( const QString& strid, int num )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return FALSE;
+    if ( !parseDat( num ) ) return FALSE;
 
-    if(m_resDatVec[num].id  == strid) return TRUE;
+    if ( m_resDatVec[ num ].id == strid ) return TRUE;
 
     return FALSE;
 }
 
 
 /* Are keywords included ? */ /* public */
-bool DatInfo::checkWord(QStringList& stlist, /* list of keywords */
-                        int num,
-                        bool checkOR /* AND or OR search */
+bool DatInfo::checkWord( QStringList& stlist,  /* list of keywords */
+                         int num,
+                         bool checkOR /* AND or OR search */
                        )
 {
     QMutexLocker locker( &m_mutex );
-    if(!parseDat(num)) return FALSE;
+    if ( !parseDat( num ) ) return FALSE;
 
     QString str_text = m_resDatVec[ num ].body;
 
-    for ( QStringList::iterator it = stlist.begin(); it != stlist.end(); ++it )
-    {
+    for ( QStringList::iterator it = stlist.begin(); it != stlist.end(); ++it ) {
 
-        QRegExp regexp( (*it) );
+        QRegExp regexp( ( *it ) );
         regexp.setCaseSensitive( FALSE );
 
-        if ( checkOR )
-        { /* OR */
-            if ( str_text.find( regexp, 0 ) != -1 )
-            {
+        if ( checkOR ) { /* OR */
+            if ( str_text.find( regexp, 0 ) != -1 ) {
                 return TRUE;
             }
-        }
-        else
-        { /* AND */
+        } else { /* AND */
             if ( str_text.find( regexp, 0 ) == -1 ) return FALSE;
         }
     }
@@ -1097,7 +1101,7 @@ void DatInfo::resetAbone()
 /* private */
 void DatInfo::resetAbonePrivate()
 {
-    for ( int i = 1; i < KITA_MAXRES; i++ )	m_resDatVec[ i ].checkAbone = FALSE;
+    for ( int i = 1; i < ( int ) m_resDatVec.size(); i++ ) m_resDatVec[ i ].checkAbone = FALSE;
 
     m_aboneByID = ( !KitaConfig::aboneIDList().empty() );
     m_aboneByName = ( !KitaConfig::aboneNameList().empty() );
@@ -1109,53 +1113,49 @@ void DatInfo::resetAbonePrivate()
 /*--------------*/
 /* check abone  */ /* public */
 
-bool DatInfo::checkAbone(int num)
+bool DatInfo::checkAbone( int num )
 {
     QMutexLocker locker( &m_mutex );
 
-    return checkAbonePrivate(num);
+    return checkAbonePrivate( num );
 }
 
 
 /* private */
-bool DatInfo::checkAbonePrivate(int num)
+bool DatInfo::checkAbonePrivate( int num )
 {
-    if(!parseDat(num)) return FALSE;
+    if ( !parseDat( num ) ) return FALSE;
 
     if ( m_resDatVec[ num ].checkAbone ) return m_resDatVec[ num ].abone;
 
     m_resDatVec[ num ].checkAbone = TRUE;
     bool checktmp = FALSE;
 
-    if( m_aboneByID )
-        checktmp = checkAboneCore(m_resDatVec[ num ].id,KitaConfig::aboneIDList());
+    if ( m_aboneByID )
+        checktmp = checkAboneCore( m_resDatVec[ num ].id, KitaConfig::aboneIDList() );
 
-    if(!checktmp && m_aboneByName )
-        checktmp = checkAboneCore(m_resDatVec[ num ].parsedName,KitaConfig::aboneNameList());
+    if ( !checktmp && m_aboneByName )
+        checktmp = checkAboneCore( m_resDatVec[ num ].parsedName, KitaConfig::aboneNameList() );
 
-    if(!checktmp && m_aboneByBody )
-        checktmp = checkAboneCore(m_resDatVec[ num ].body,KitaConfig::aboneWordList());
+    if ( !checktmp && m_aboneByBody )
+        checktmp = checkAboneCore( m_resDatVec[ num ].body, KitaConfig::aboneWordList() );
 
-    if(!checktmp && m_aboneByRes )
-    {
-        setAncList(num);
+    if ( !checktmp && m_aboneByRes ) {
+        setAncList( num );
         AncList& anclist = m_resDatVec[ num ].anclist;
 
         for ( AncList::iterator it = anclist.begin();
-                it != anclist.end() && !checktmp ; ++it )
-        {
+                it != anclist.end() && !checktmp ; ++it ) {
 
-            int refNum = (*it).from;
-            int refNum2 = (*it).to;
+            int refNum = ( *it ).from;
+            int refNum2 = ( *it ).to;
 
             /* I don't want to enter loop... */
             if ( refNum >= num ) continue;
             if ( refNum2 >= num ) refNum2 = num - 1;
 
-            for (int  i = refNum; i <= refNum2; i++ )
-            {
-                if (checkAbonePrivate(i))
-                {
+            for ( int i = refNum; i <= refNum2; i++ ) {
+                if ( checkAbonePrivate( i ) ) {
                     checktmp = TRUE;
                     break;
                 }
@@ -1169,18 +1169,15 @@ bool DatInfo::checkAbonePrivate(int num)
 }
 
 /* private */
-bool DatInfo::checkAboneCore(const QString& str, QStringList& strlist)
+bool DatInfo::checkAboneCore( const QString& str, QStringList& strlist )
 {
-    if(strlist.count())
-    {
+    if ( strlist.count() ) {
 
         int i;
         for ( QStringList::iterator it = strlist.begin();
-                it != strlist.end(); ++it )
-        {
+                it != strlist.end(); ++it ) {
             i = str.find( ( *it ) );
-            if ( i != -1 )
-            {
+            if ( i != -1 ) {
                 return TRUE;
             }
         }
@@ -1207,15 +1204,14 @@ bool DatInfo::checkAboneCore(const QString& str, QStringList& strlist)
 bool DatInfo::parseDat( int num )
 {
 
-    if ( num <= 0 || KITA_MAXRES <= num ) return FALSE;
-    if( m_resDatVec[ num ].parsed ) return TRUE;
+    if ( num <= 0 || ( int ) m_resDatVec.size() <= num ) return FALSE;
+    if ( m_resDatVec[ num ].parsed ) return TRUE;
 
     QString tmpstr;
-    if( !ParseMisc::parseResDat( m_resDatVec[ num ], tmpstr ) ) return FALSE;
+    if ( !ParseMisc::parseResDat( m_resDatVec[ num ], tmpstr ) ) return FALSE;
 
     /* get subject */
-    if ( m_subject == QString::null && tmpstr != QString::null )
-    {
+    if ( m_subject == QString::null && tmpstr != QString::null ) {
         m_subject = tmpstr;
         Kita::Thread::setName( m_datURL.prettyURL(), m_subject );
     }
