@@ -35,6 +35,7 @@ void FavoriteBoards::append( KURL& url )
 {
     if ( ! getInstance() ->m_list.contains( url ) ) {
         getInstance() ->m_list.append( url );
+        getInstance()->notifyChange();
     }
 }
 
@@ -42,6 +43,7 @@ void FavoriteBoards::remove( KURL& url )
 {
     if ( getInstance() ->m_list.contains( url ) ) {
         getInstance() ->m_list.remove( url );
+        getInstance()->notifyChange();
     }
 }
 
@@ -87,7 +89,9 @@ void FavoriteBoards::processChildNode( QDomNode& node )
     KURL url = KURL( urlText );
     if ( url.isValid() ) {
         Kita::Board::setName( urlText, nameText );
-        FavoriteBoards::append( url );
+        //FavoriteBoards::append( url );
+        if ( !getInstance()->m_list.contains( url ) )
+            getInstance()->m_list.append( url );
     }
 }
 
@@ -112,7 +116,7 @@ QString FavoriteBoards::toXML()
         board.appendChild( urlElement );
         urlElement.appendChild( document.createTextNode( boardURL ) );
     
-        QString boardName = Kita::Board::getByURL( boardURL )->name();
+        QString boardName = Kita::Board::getName( boardURL );
         QDomElement nameElement = document.createElement( "name" );
         board.appendChild( nameElement );
         nameElement.appendChild( document.createTextNode( boardName ) );
@@ -133,5 +137,12 @@ void FavoriteBoards::replace( QString fromURL, QString toURL )
             it = boardList.begin();
         }
     }
+    FavoriteBoards::getInstance()->notifyChange();
 }
 
+void FavoriteBoards::notifyChange()
+{
+    emit changed();
+}
+
+#include "favoriteboards.moc"
