@@ -10,6 +10,7 @@
 #ifndef KITAFAVORITEBOARDS_H
 #define KITAFAVORITEBOARDS_H
 
+#include <qobject.h>
 #include <kurl.h>
 
 class QDomNode;
@@ -19,14 +20,19 @@ namespace Kita
     /**
     @author Hideki Ikemoto
     */
-    class FavoriteBoards
+    class FavoriteBoards : public QObject
     {
+
+        Q_OBJECT
+
         static FavoriteBoards* instance;
         QValueList<KURL> m_list;
         FavoriteBoards();
         ~FavoriteBoards();
 
         static void processChildNode( QDomNode& node );
+    private:
+        void notifyChange();
     public:
         static FavoriteBoards* getInstance();
         static void append( KURL& url );
@@ -35,7 +41,9 @@ namespace Kita
         static bool readFromXML( QString& xml );
         static QString toXML();
         static void replace( QString fromURL, QString toURL );
+    signals:
+        void changed();
     };
-};
+}
 
 #endif
