@@ -13,6 +13,8 @@
 
 #include <qstring.h>
 
+class KURL;
+
 namespace Kita
 {
     enum {
@@ -35,6 +37,9 @@ namespace Kita
     QString unescape( const QString& str );
     int boardType( const QString& url );
     uint datToSince( const QString& datURL );
+    QString datToOfflaw( const QString& datURL );
+    bool is2ch( const KURL& url );
+    QString parse_machibbs_dat( const QString& datStr );
 }
 
 #endif
