@@ -19,23 +19,15 @@
 class BoardTest : public CppUnit::TestFixture {
     CPPUNIT_TEST_SUITE( BoardTest );
     CPPUNIT_TEST( testID );
-    CPPUNIT_TEST( testName );
-    CPPUNIT_TEST( testSubjectTxtURL );
-    CPPUNIT_TEST( testURL );
     CPPUNIT_TEST( testStaticName );
     CPPUNIT_TEST( testReplace );
     CPPUNIT_TEST_SUITE_END();
 
-    Kita::Board *m_normal, *m_share1, *m_share2, *m_share3, *m_null;
-    Kita::Board *m_fromxml, *m_fromxml2;
 public:
     void setUp();
     void tearDown();
 
     void testID();
-    void testName();
-    void testSubjectTxtURL();
-    void testURL();
     void testStaticName();
     void testReplace();
 };
