@@ -13,13 +13,11 @@
 
 #include "k2ch_articlefiletest.h"
 #include "urlconverttest.h"
-#include "commenttest.h"
 #include "threadtest.h"
 #include "boardtest.h"
 #include "misctest.h"
 #include "favoritethreadstest.h"
 #include "favoriteboardstest.h"
-#include "commentlisttest.h"
 #include "cachetest.h"
 
 int main( int argc, char* argv[] )
@@ -28,13 +26,11 @@ int main( int argc, char* argv[] )
 
   runner.addTest( K2chArticleFileTest::suite() );
   runner.addTest( URLConvertTest::suite() );
-  runner.addTest( CommentTest::suite() );
   runner.addTest( ThreadTest::suite() );
   runner.addTest( BoardTest::suite() );
   runner.addTest( MiscTest::suite() );
   runner.addTest( FavoriteThreadsTest::suite() );
   runner.addTest( FavoriteBoardsTest::suite() );
-  runner.addTest( CommentListTest::suite() );
   runner.addTest( CacheTest::suite() );
   runner.run( "" );
   return 0;
