@@ -43,6 +43,9 @@ class URLConvertTest : public CppUnit::TestFixture
     QString m_boardURL2_k2ch;
     QString m_cachePath;
     QString m_cachePath_k2ch;
+    
+    QString m_machibbsDatURL;
+    QString m_machibbsThreadURL;
 
 public:
     void setUp();
