@@ -41,17 +41,13 @@ namespace Kita
 
         const QString& datURL() const;
         const QString url() const;
-        const QString datID() const;
         const QString& name() const;
-        void setResNum( int resNum );
         int resNum() const;
         const QString& boardName() const;
-        const QString boardURL() const;
-        const QString boardID() const;
 
         static Thread* getByURL( const QString& datURL );
-	static Thread* getByURLNew( const KURL& datURL );
-        static void setName( const QString& datURL, const QString& threadName );
+        static Thread* getByURLNew( const KURL& datURL );
+        static void setName( const QString& datURL, QString threadName );
         static void replace( const QString& fromURL, const QString& toURL );
     private:
         QString m_datURL;
