@@ -638,13 +638,12 @@ void KitaDomTree::createKokoyon()
     DOM::Element rootnode;
 
     str = Kita::ParseMisc::utf8ToUnicode( KITAUTF8_KOKOYON2 );
-    style = "background-color: #CCCCCC; text-align: center";
 
     rootnode = m_hdoc.createElement( "DIV" );
     {
+        rootnode.setAttribute( "class", "kokoyon" );
         rootnode.setAttribute( "kita_type", "kokoyon" );
         rootnode.setAttribute( "id", "kokomade_yonda" );
-        rootnode.setAttribute( "style", style );
         rootnode.appendChild( m_hdoc.createTextNode( str ) );
     }
 
