@@ -20,7 +20,6 @@ public:
     virtual ~KitaThreadPart();
 
     static KAboutData * createAboutData(); //needed by GenericFactory
-    void setupActions();
 
     KParts::BrowserExtension *browserExtension() const;
 
@@ -32,7 +31,7 @@ public slots:
 
 protected:
     virtual bool openFile() { return false; };
-    virtual void guiActivateEvent ( KParts::GUIActivateEvent *event );
+    virtual void partActivateEvent ( KParts::PartActivateEvent *event );
 
 protected slots:
     void slotOpenURLResult();
