@@ -45,7 +45,6 @@
 #include "kitahtmlpart.h"
 #include "kitawritedialog.h"
 #include "kita2ch.h"
-#include "kitanavi.h"
 
 #include "libkita/kitaconfig.h"
 #include "libkita/kita-utf8.h"
@@ -61,13 +60,6 @@
 
 #define MAX_LABEL_LENGTH 60
 
-static const char* cookie_title = "񤭹߳ǧ";
-static const char* cookie_message =
-    "Ƴǧ\n"
-    "Ƥ줿Ƥϥԡ¸ѡž礬ޤ\n"
-    "Ƥ˴ؤȯǤƼԤ˵ޤ\n"
-    "\n"
-    "Ǥ餦Ȥƽ񤭹ߤޤ\n";
 
 KitaThreadView::KitaThreadView( QWidget* parent, const char* name )
         : KitaThreadViewBase( parent, name )
@@ -94,6 +86,7 @@ KitaThreadView::KitaThreadView( QWidget* parent, const char* name )
         BookmarkButton->setPixmap( SmallIcon( "bookmark_add" ) );
         writeButton->setPixmap( SmallIcon( "pencil" ) );
         deleteButton->setPixmap( SmallIcon( "edittrash" ) );
+        closeButton->setPixmap( SmallIcon( "fileclose" ) );
     }
 
     setAcceptDrops( true ); // DND Drop eneble: 2nd stage. - enable on "KitaThreadView" widget and disable on the others(child widgets of "KitaThreadView").
@@ -112,6 +105,9 @@ KitaThreadView::KitaThreadView( QWidget* parent, const char* name )
              SLOT( slotUpdateInfo() ) );
     connect( m_threadPart, SIGNAL( nodeActivated( const DOM::Node& ) ),
              SLOT( slotDOMNodeActivated( const DOM::Node& ) ) );
+    connect( m_threadPart, SIGNAL( mousePressed() ),
+             SLOT( setFocus() ) );
+
     connect( BookmarkButton, SIGNAL( toggled( bool ) ),
              SLOT( slotBookmarkButtonClicked( bool ) ) );
     connect( SearchButton, SIGNAL( clicked() ),
@@ -124,6 +120,8 @@ KitaThreadView::KitaThreadView( QWidget* parent, const char* name )
              SLOT( slotReloadButton() ) );
     connect( gotoCombo, SIGNAL( activated( int ) ),
              SLOT( slotComboActivated( int ) ) );
+    connect( closeButton, SIGNAL( clicked() ),
+             SLOT( slotCloseButton() ) );
 
     Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
     connect( this, SIGNAL( setMainStatusbar( const QString& ) ),
@@ -133,27 +131,38 @@ KitaThreadView::KitaThreadView( QWidget* parent, const char* name )
     connect( this, SIGNAL( setMainURLLine( const KURL& ) ),
              signalCollection, SIGNAL( setMainURLLine( const KURL& ) ) );
     connect( this, SIGNAL( updateSubjectTab( const KURL& ) ),
-             signalCollection, SIGNAL( updateSubjectTab( const KURL& ) ));
+             signalCollection, SIGNAL( updateSubjectTab( const KURL& ) ) );
     connect( this, SIGNAL( updateThreadTab( const KURL& ) ),
-             signalCollection, SIGNAL( updateThreadTab( const KURL& ) ));
+             signalCollection, SIGNAL( updateThreadTab( const KURL& ) ) );
     connect( this, SIGNAL( openBoardRequested( const QString&, bool ) ),
              signalCollection, SIGNAL( openBoardRequested( const QString&, bool ) ) );
     connect( this, SIGNAL( setMainCaption( const QString& ) ),
              signalCollection, SIGNAL( setMainCaption( const QString& ) ) );
     connect( this, SIGNAL( closeThreadTab( const KURL& ) ),
-             signalCollection, SIGNAL( closeThreadTab( const KURL& ) ));
+             signalCollection, SIGNAL( closeThreadTab( const KURL& ) ) );
 
-    m_viewmode = VIEWMODE_PARENT;
+    connect( this, SIGNAL( activateThreadView( const KURL& ) ),
+             signalCollection, SIGNAL( activateThreadView( const KURL& ) ) );
+
+    /* Kita Navi */
+    connect( this, SIGNAL( showKitaNaviByWord( const KURL& , QString ) ),
+             signalCollection, SIGNAL( showKitaNaviByWord( const KURL& , QString ) ) );
+
+    /* write dock */
+    connect( this, SIGNAL( showWriteView( const KURL& , const QString&, const QString& ) ),
+             signalCollection, SIGNAL( showWriteView( const KURL& , const QString&, const QString& ) ) );
+
+    m_viewmode = VIEWMODE_MAINVIEW;
     m_rescode = 200;
     m_serverTime = 0;
     m_datURL = QString::null;
+
 }
 
 KitaThreadView::~KitaThreadView()
 {
 
-    if ( m_threadPart )
-    {
+    if ( m_threadPart ) {
         delete m_threadPart;
         m_threadPart = NULL;
     }
@@ -169,13 +178,17 @@ const KURL KitaThreadView::threadURL() const
     return Kita::DatManager::threadURL( m_datURL );
 }
 
+const KURL KitaThreadView::datURL() const
+{
+    return m_datURL;
+}
+
 void KitaThreadView::slotDOMNodeActivated( const DOM::Node& node )
 {
     { //process Anchor tags. Anchor tags not proccessed here cause 'emit KParts::BrowserExtention::openURLRequest()'
         DOM::HTMLAnchorElement anchor = node;
 
-        if ( ! anchor.href().isEmpty() )
-        {
+        if ( ! anchor.href().isEmpty() ) {
             kdDebug() << "AnchorNodeActivated::" << endl;
         } // end: anchor.href().isEmpty()
     } // end of Anchor tags.
@@ -184,12 +197,9 @@ void KitaThreadView::slotDOMNodeActivated( const DOM::Node& node )
 void KitaThreadView::setSubjectLabel( const QString& boardName, const QString& threadName, const QString boardURL )
 {
     QString disp;
-    if ( boardName.isEmpty() )
-    {
+    if ( boardName.isEmpty() ) {
         disp = threadName;
-    }
-    else
-    {
+    } else {
         disp = QString( "<a href=\"%1\">[%2]</a> %3" ).arg( boardURL ).arg( boardName ).arg( threadName );
     }
 
@@ -197,15 +207,15 @@ void KitaThreadView::setSubjectLabel( const QString& boardName, const QString& t
     subjectLabel->setText( disp );
 }
 
-void KitaThreadView::subjectlinkClicked(const QString& URL )
+void KitaThreadView::subjectlinkClicked( const QString& URL )
 {
-    kdDebug() << QString("Jump board: \"%1\"").arg(URL) << endl;
+    kdDebug() << QString( "Jump board: \"%1\"" ).arg( URL ) << endl;
     emit openBoardRequested( URL, KitaConfig::alwaysUseTab() );
 }
 
 void KitaThreadView::subjectlinkMClicked( const QString &URL )
 {
-    kdDebug() << QString("Jump board as new tab: \"%1\"").arg(URL) << endl;
+    kdDebug() << QString( "Jump board as new tab: \"%1\"" ).arg( URL ) << endl;
     emit openBoardRequested( URL, TRUE );
 }
 
@@ -214,116 +224,37 @@ void KitaThreadView::updateButton()
     writeButton->setEnabled( true );
     BookmarkButton->setEnabled( true );
     ReloadButton->setEnabled( true );
+    deleteButton->setEnabled( true );
+    closeButton->setEnabled( true );
 
-    if ( HighLightButton->isOn() )
-    {
+    if ( HighLightButton->isOn() ) {
         HighLightButton->toggle();
     }
-    if ( FavoriteThreads::getInstance() ->contains( m_datURL.prettyURL() ) )
-    {
+
+    // don't emit SIGNAL( toggled() )
+    disconnect( BookmarkButton, SIGNAL( toggled( bool ) ), this, SLOT( slotBookmarkButtonClicked( bool ) ) );
+    if ( FavoriteThreads::getInstance() ->contains( m_datURL.prettyURL() ) ) {
         BookmarkButton->setOn( true );
-    }
-    else
-    {
+    } else {
         BookmarkButton->setOn( false );
     }
+    connect( BookmarkButton, SIGNAL( toggled( bool ) ), SLOT( slotBookmarkButtonClicked( bool ) ) );
 }
 
 
-void KitaThreadView::slotShowErrorDialog( const QString& input, const KURL& )
-{
-    QTextCodec * eucjpCodec = QTextCodec::codecForName( "euc-jp" );
-
-    kdDebug() << "'" << input << "'" << endl;
-    Kita::WriteResult writeResult( input );
-
-    kdDebug() << "code = " << writeResult.code() << endl;
-    switch ( writeResult.code() )
-    {
-    case Kita::K2ch_Unknown:
-        // probably OK.
-        slotReloadButton();
-        break;
-    case Kita::K2ch_True:
-    case Kita::K2ch_False:
-    case Kita::K2ch_Check:
-        break;
-    case Kita::K2ch_Error:
-        {
-            KMessageBox::error( 0, writeResult.message(), writeResult.title() );
-            KitaWriteDialog* dialog = openDialog( m_postInfo );
-            dialog->show();
-        }
-        break;
-    case Kita::K2ch_Cookie:
-        if ( KMessageBox::questionYesNo( 0, eucjpCodec->toUnicode( cookie_message ),
-                                         eucjpCodec->toUnicode( cookie_title ) )
-                == KMessageBox::Yes )
-        {
-            KitaWriteDialog * dialog = openDialog( m_postInfo );
-            dialog->postMessage();
-        }
-        else
-        {
-            KitaWriteDialog* dialog = openDialog( m_postInfo );
-            dialog->show();
-        }
-        break;
-    default:
-        break;
-    }
-}
-
-KitaWriteDialog* KitaThreadView::openDialog( const Kita::PostInfo& info )
-{
-    KitaWriteDialog * new_dialog = KitaWriteDialog::open( info, m_datURL, this );
-    connect( new_dialog, SIGNAL( postStarted( KIO::Job*, const Kita::PostInfo& ) ),
-             this, SLOT( slotPostStarted( KIO::Job*, const Kita::PostInfo& ) ) );
-    connect( new_dialog, SIGNAL( postResponse( const QString&, const KURL& ) ),
-             this, SLOT( slotShowErrorDialog( const QString&, const KURL& ) ) );
-    connect( new_dialog, SIGNAL( postResponse( const QString&, const KURL& ) ),
-             this, SIGNAL( postResponse( const QString&, const KURL& ) ) );
-    return new_dialog;
-}
-
 /*--------------------*/
 /* write response     */
 /*--------------------*/  /* private slots */
 void KitaThreadView::slotWriteButtonClicked( QString resstr )
 {
-    m_serverTime = Kita::DatManager::getServerTime(m_datURL);
-    if ( ! m_serverTime ) return ;
-
-    // TODO: machiBBS kakiko support.
-    if ( Kita::Board::isWritingSupported( m_datURL ) == false )
-    {
-        QMessageBox::warning( this, QString("<(_ _)>"),
-                              i18n("Can't write to machi BBS in this version." ) );
-        return;
-    }
-
-    KURL bbscgiURL = KURL( Kita::DatManager::boardURL( m_datURL ), "../test/bbs.cgi" );
-    bbscgiURL.setProtocol( "http" );
-
-    Kita::PostInfo info;
-    info.host = bbscgiURL.host();
-    info.bbs = Kita::DatManager::boardID( m_datURL );
-    info.key = Kita::DatManager::threadID( m_datURL );
-    info.time = QString( "%1" ).arg( m_serverTime );
-    info.body = resstr;
-    info.mail = m_mailaddr;
-
-    KitaWriteDialog* dialog = openDialog( info );
-    dialog->show(); // work asynchronus.
+    emit showWriteView( m_datURL, resstr, m_mailaddr );
 }
 
 
 void KitaThreadView::insertSearchCombo()
 {
-    for ( int count = 0; count < SearchCombo->count(); ++count )
-    {
-        if ( SearchCombo->text( count ) == SearchCombo->currentText() )
-        {
+    for ( int count = 0; count < SearchCombo->count(); ++count ) {
+        if ( SearchCombo->text( count ) == SearchCombo->currentText() ) {
             // found
             return ;
         }
@@ -361,10 +292,6 @@ void KitaThreadView::setFont( const QFont& font )
     style.setProperty( "font-size", QString( "%1pt" ).arg( font.pointSize() ), "" );
 }
 
-void KitaThreadView::slotPostStarted( KIO::Job*, const Kita::PostInfo& info )
-{
-    m_postInfo = info;
-}
 
 void KitaThreadView::slotBookmarkButtonClicked( bool on )
 {
@@ -377,59 +304,73 @@ void KitaThreadView::focusSearchCombo()
     if ( ! SearchCombo->hasFocus() ) {
         SearchCombo->setFocus();
     } else {
-        m_threadPart->view()->setFocus();
+        setFocus();
     }
 }
 
+
+/* public slot */ /* virtual */
+void KitaThreadView::setFocus()
+{
+    emit activateThreadView( m_datURL );
+
+    showStatusBar( QString::null );
+
+    QWidget* topWidget = topLevelWidget();
+    if ( topWidget->isMinimized() ) topWidget->showNormal();
+    topWidget->raise();
+    topWidget->setActiveWindow();
+    m_threadPart->view() ->setFocus();
+}
+
 namespace Kita
 {
 
-    KitaSubjectLabel::KitaSubjectLabel(QWidget* parent, const char * name )
-            : KTextBrowser(parent, name)
+    KitaSubjectLabel::KitaSubjectLabel( QWidget* parent, const char * name )
+            : KTextBrowser( parent, name )
     {
-        setTextFormat(Qt::RichText);
-        setVScrollBarMode(QScrollView::AlwaysOff);
-        setHScrollBarMode(QScrollView::AlwaysOff);
+        setTextFormat( Qt::RichText );
+        setVScrollBarMode( QScrollView::AlwaysOff );
+        setHScrollBarMode( QScrollView::AlwaysOff );
         setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
         setNotifyClick( TRUE );
-        setFrameStyle(QFrame::NoFrame);
+        setFrameStyle( QFrame::NoFrame );
         paletteChanged();
-        if (kapp)
-        {
-            connect(kapp, SIGNAL(kdisplayPaletteChanged()),
-                    this, SLOT(paletteChanged()));
+        if ( kapp ) {
+            connect( kapp, SIGNAL( kdisplayPaletteChanged() ),
+                     this, SLOT( paletteChanged() ) );
         }
     }
 
     void KitaSubjectLabel::paletteChanged()
     {
         QPalette p = kapp ? kapp->palette() : palette();
-        p.setBrush(QColorGroup::Base, p.brush(QPalette::Normal, QColorGroup::Background));
-        p.setColor(QColorGroup::Text, p.color(QPalette::Normal, QColorGroup::Foreground));
-        setPalette(p);
+        p.setBrush( QColorGroup::Base, p.brush( QPalette::Normal, QColorGroup::Background ) );
+        p.setColor( QColorGroup::Text, p.color( QPalette::Normal, QColorGroup::Foreground ) );
+        setPalette( p );
     }
 
     QSize KitaSubjectLabel::minimumSizeHint() const
     {
         QSize ms = minimumSize();
-        if ((ms.width() > 0) && (ms.height() > 0))
+        if ( ( ms.width() > 0 ) && ( ms.height() > 0 ) )
             return ms;
 
         int w = 400;
-        if (ms.width() > 0)
+        if ( ms.width() > 0 )
             w = ms.width();
 
         QString txt = text();
-        QSimpleRichText rt(txt, font());
-        rt.setWidth(w - 2*frameWidth() - 10);
-        w = 10 + rt.widthUsed() + 2*frameWidth();
-        if (w < ms.width())
+        QSimpleRichText rt( txt, font() );
+        rt.setWidth( w - 2 * frameWidth() - 10 );
+        w = 10 + rt.widthUsed() + 2 * frameWidth();
+        if ( w < ms.width() )
             w = ms.width();
-        int h = rt.height() + 2*frameWidth();
-        if ( h < ms.height())
+        int h = rt.height() + 2 * frameWidth();
+        if ( h < ms.height() )
             h = ms.height();
 
-        return QSize(w, h);
+        return QSize( w, h );
     }
 
     QSize KitaSubjectLabel::sizeHint() const
@@ -440,8 +381,7 @@ namespace Kita
     {
         KTextBrowser::contentsMousePressEvent( e );
         kdDebug() << "Press Button:" << QString::number( e->button() ) << endl;
-        if ( e->button() == Qt::MidButton )
-        {
+        if ( e->button() == Qt::MidButton ) {
             QString t = text();
             QSimpleRichText rt( t, font() );
             m_popupURL = rt.anchorAt( e->pos() );
@@ -460,19 +400,17 @@ namespace Kita
         QString t = text();
         QSimpleRichText rt( t, font() );
         m_popupURL = rt.anchorAt( pos );
-        kdDebug() << QString( "popupMenu for \"%1\"").arg( m_popupURL ) << endl
+        kdDebug() << QString( "popupMenu for \"%1\"" ).arg( m_popupURL ) << endl
         ;
-        if ( !m_popupURL.isEmpty() )
-        {
-            QPopupMenu *popup = new QPopupMenu;
+        if ( !m_popupURL.isEmpty() ) {
+            QPopupMenu * popup = new QPopupMenu;
             popup->insertItem( i18n( "Open with new tab" ), this, SLOT( popupOpenAsNewTab() ) );
             popup->insertItem( i18n( "Copy title and URL" ), this, SLOT( popupCopyToClipboard() ) );
             QString ft = Kita::FavoriteBoards::boards().contains( KURL( m_popupURL ) ) ?
-                         i18n( "Remove from Favorites" ) : i18n( "Add to Favorites") ;
+                         i18n( "Remove from Favorites" ) : i18n( "Add to Favorites" ) ;
             popup->insertItem( ft, this, SLOT( popupFavorites() ) );
             return popup;
-        }
-        else return NULL;
+        } else return NULL;
     }
 
     void KitaSubjectLabel::popupOpenAsNewTab()
@@ -484,7 +422,7 @@ namespace Kita
     void KitaSubjectLabel::popupCopyToClipboard()
     {
         QClipboard * clipboard = QApplication::clipboard();
-        QString text = QString("%1\n%2").arg( Kita::Board::getName( m_popupURL ) ).arg( m_popupURL );
+        QString text = QString( "%1\n%2" ).arg( Kita::Board::getName( m_popupURL ) ).arg( m_popupURL );
         kdDebug() << "popupCopytoClipboard :" << endl << text << endl;
         clipboard->setText( text , QClipboard::Clipboard );
         clipboard->setText( text , QClipboard::Selection );
@@ -492,8 +430,7 @@ namespace Kita
 
     void KitaSubjectLabel::popupFavorites()
     {
-        if ( !m_popupURL.isEmpty() )
-        {
+        if ( !m_popupURL.isEmpty() ) {
             KURL u = KURL( m_popupURL );
             if ( Kita::FavoriteBoards::boards().contains( u ) )
                 Kita::FavoriteBoards::remove( u );
@@ -527,7 +464,7 @@ void KitaThreadView::setup( const KURL& datURL, int mode )
 
     /* setup HTMLPart */
     int partMode = HTMLPART_MODE_MAINPART;
-    if( mode == VIEWMODE_KITANAVI ) partMode = HTMLPART_MODE_NAVI;
+    if ( mode == VIEWMODE_KITANAVI ) partMode = HTMLPART_MODE_NAVI;
     m_threadPart->setup( partMode, m_datURL );
 
     /* mode. Mode is defined in kitathreadview.h */
@@ -545,18 +482,20 @@ void KitaThreadView::setup( const KURL& datURL, int mode )
 void KitaThreadView::showThread( const KURL& datURL, int num )
 {
     /* If this widget is not parent, then do nothing. */
-    if ( m_viewmode != VIEWMODE_PARENT ) return ;
+    if ( m_viewmode != VIEWMODE_MAINVIEW ) return ;
+
+    if ( num == 0 ) num = Kita::DatManager::getKokoyonNum( datURL );
 
     if ( topLevelWidget() ->isMinimized() ) topLevelWidget() ->showNormal();
     topLevelWidget() ->raise();
     setActiveWindow();
 
     /* setup */
-    setup( datURL, VIEWMODE_PARENT );
+    setup( datURL, VIEWMODE_MAINVIEW );
 
     /* get log from cahce */
     m_rescode = 200;
-    if( !m_threadPart->load( num ) ) showStatusBar( "" );
+    if ( !m_threadPart->load( num ) ) showStatusBar( "" );
 
     /* update data */
     slotUpdateInfo();
@@ -568,13 +507,12 @@ void KitaThreadView::showThread( const KURL& datURL, int num )
 /*---------*/
 /* reload  */
 /*---------*/ /* public slot */
-void KitaThreadView::slotReloadButton()
+void KitaThreadView::slotReloadButton( int jumpNum )
 {
     topLevelWidget() ->raise();
     setActiveWindow();
 
-    if( m_threadPart->reload() )
-    {
+    if ( m_threadPart->reload( jumpNum ) ) {
         showStatusBar( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_NOWRENEW ) );
     }
 }
@@ -584,7 +522,19 @@ void KitaThreadView::slotReloadButton()
 /* stop loading the thread           */ /* public slot */
 void KitaThreadView::slotStopLoading()
 {
-    Kita::DatManager::stopLoading(m_datURL);
+    /* hide popup */
+    if ( m_threadPart->isPopupVisible() ) {
+        m_threadPart->slotDeletePopup();
+        return ;
+    }
+
+    /* unforcus search combo */
+    if ( SearchCombo->hasFocus() ) {
+        setFocus();
+        return ;
+    }
+
+    Kita::DatManager::stopLoading( m_datURL );
 }
 
 
@@ -593,35 +543,40 @@ void KitaThreadView::slotStopLoading()
 /*-----------------------------------------*/
 void KitaThreadView::showStatusBar( QString info )
 {
+    if ( m_datURL.isEmpty() ) return ;
     int totalNum = 0, datSize = 0;;
     bool broken = FALSE;
+    QString captionStr = QString::null;
     QString infostr = QString::null;
     QString errstr = QString::null;
-    int kokoyonNum = Kita::DatManager::getKokoyonNum(m_datURL);
+    int kokoyonNum = Kita::DatManager::getKokoyonNum( m_datURL );
 
-    switch( m_viewmode )
-    {
+    switch ( m_viewmode ) {
 
-    case VIEWMODE_PARENT:
+    case VIEWMODE_MAINVIEW:
 
-        totalNum = Kita::DatManager::getReadNum(m_datURL);
-        broken = Kita::DatManager::isBroken(m_datURL);
-        datSize =  Kita::DatManager::getDatSize(m_datURL);
+        totalNum = Kita::DatManager::getReadNum( m_datURL );
+        broken = Kita::DatManager::isBroken( m_datURL );
+        datSize = Kita::DatManager::getDatSize( m_datURL );
 
         errstr = QString::null;
-        if ( m_rescode != 200 && m_rescode != 206 )
+        if ( m_rescode != 200 && m_rescode != 206 && m_rescode != 0 )
             errstr = QString( "Error %1" ).arg( m_rescode );
         if ( broken ) info += " This thread is broken.";
 
-        /* show status bar */
+        /* show status bar,caption, url  */
         infostr = Kita::DatManager::threadName( m_datURL ) +
                   QString( " [Total: %1 New: %2] %3 k" ).arg( totalNum ).arg( totalNum - kokoyonNum ).arg( datSize / 1024 )
                   + info + " " + errstr;
 
+        captionStr = Kita::DatManager::thread_name( m_datURL )
+                     + QString( " (%1)" ).arg( Kita::DatManager::getReadNum( m_datURL ) );
+
+        emit setMainCaption( captionStr );
         emit setMainStatusbar( infostr );
         emit setMainURLLine( Kita::DatManager::threadURL( m_datURL ) );
 
-        return;
+        return ;
         break;
 
     default:
@@ -637,23 +592,21 @@ void KitaThreadView::showStatusBar( QString info )
 /* update information */ /* public */
 void KitaThreadView::slotUpdateInfo()
 {
-    m_rescode = Kita::DatManager::getResponseCode(m_datURL);
-    m_serverTime = Kita::DatManager::getServerTime(m_datURL);
+    m_rescode = Kita::DatManager::getResponseCode( m_datURL );
+    m_serverTime = Kita::DatManager::getServerTime( m_datURL );
 
     /* uptate informations */
-    setSubjectLabel(Kita::DatManager::thread_boardName(m_datURL),
-                    Kita::DatManager::thread_name(m_datURL)
-                    + QString( " (%1)" )
-                    .arg( Kita::DatManager::getReadNum(m_datURL) ),
-                    Kita::DatManager::thread_boardURL( m_datURL ) );
-    emit setMainURLLine( Kita::DatManager::thread_url(m_datURL) );
+    setSubjectLabel( Kita::DatManager::thread_boardName( m_datURL ),
+                     Kita::DatManager::thread_name( m_datURL )
+                     + QString( " (%1)" )
+                     .arg( Kita::DatManager::getReadNum( m_datURL ) ),
+                     Kita::DatManager::thread_boardURL( m_datURL ) );
     updateButton();
 
     gotoCombo->clear();
     gotoCombo->insertItem( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_GOTO ) );
     gotoCombo->insertItem( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_KOKOYON ) );
-    for( int i = 1; i < Kita::DatManager::getReadNum(m_datURL); i += 100 )
-    {
+    for ( int i = 1; i < Kita::DatManager::getReadNum( m_datURL ); i += 100 ) {
         gotoCombo->insertItem( QString().setNum( i ) + "-" );
     }
     gotoCombo->insertItem( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_SAIGO ) );
@@ -662,9 +615,6 @@ void KitaThreadView::slotUpdateInfo()
     emit updateSubjectTab( m_datURL );
     emit updateThreadTab( m_datURL );
 
-    QString captionStr = Kita::DatManager::thread_name( m_datURL )
-                         + QString( " (%1)" ).arg( Kita::DatManager::getReadNum( m_datURL ) );
-    emit setMainCaption( captionStr );
     showStatusBar( "" );
 
     emit showThreadCompleted(); /* to KitaThreadPart */
@@ -680,33 +630,46 @@ void KitaThreadView::slotSearchButton()
 {
     if ( m_datURL.isEmpty() ) return ; /* Nothing is shown on the screen.*/
 
-    /* jump */
     QString str = SearchCombo->currentText();
-    if ( str.at( 0 ) == ':' )
-    {
+    if ( str.at( 0 ) == ':' ) {
+
+        /* show res popup */
+        if ( str.at( 1 ) == 'p' ) {
+            int refNum = str.mid( 2 ).toInt();
+            QPoint pos = mapToGlobal( SearchCombo->pos() );
+            pos.setY( pos.y() + SearchCombo->height() / 2 );
+            m_threadPart->slotShowResPopup( pos , refNum, refNum );
+            return ;
+        }
+        /* extract responses by keywords */
+        else if ( str.at( 1 ) == '?' ) {
+            QString query = str.mid( 2 );
+            emit showKitaNaviByWord( m_datURL, query );
+            return ;
+        }
+        /* find by find dialog */
+        else if ( str.at( 1 ) == 'f' ) {
+            KAction * act = static_cast< KAction* >( m_threadPart->action( "find" ) );
+            if ( act ) act->activate();
+            return ;
+        }
+
+        /* jump */
         QString anc = str.mid( 1 );
         m_threadPart->gotoAnchor( anc, FALSE );
         SearchCombo->setFocus();
         return ;
     }
 
-    /* extract responses by keywords */
-    else if(str.at(0) == '?')
-    {
-        QString query = str.mid(1);
-        KitaNavi::showKitaNaviByWord(m_datURL,query);
-        return;
-    }
-
     /* if this is parent, then show all responses, and search */
-    if ( m_viewmode == VIEWMODE_PARENT ) m_threadPart->showAll();
+    if ( m_viewmode == VIEWMODE_MAINVIEW ) m_threadPart->showAll();
 
     slotSearchPrivate( FALSE );
 }
 
 /* public slot */
-void KitaThreadView::slotSearchNext(){ slotSearchPrivate( FALSE ); }
-void KitaThreadView::slotSearchPrev(){ slotSearchPrivate( TRUE ); }
+void KitaThreadView::slotSearchNext() { slotSearchPrivate( FALSE ); }
+void KitaThreadView::slotSearchPrev() { slotSearchPrivate( TRUE ); }
 
 /* private */
 void KitaThreadView::slotSearchPrivate( bool rev )
@@ -715,41 +678,36 @@ void KitaThreadView::slotSearchPrivate( bool rev )
 
     /* jump */
     QString str = SearchCombo->currentText();
-    if( str == QString::null ) return;
-    if( str == "" ) return;
-    if( str.at( 0 ) == ':' ) return;
-    if( str.at(0) == '?' ) return;
+    if ( str == QString::null ) return ;
+    if ( str == "" ) return ;
+    if ( str.at( 0 ) == ':' ) return ;
+    if ( str.at( 0 ) == '?' ) return ;
 
     /* if this is parent, then show all responses, and search */
-    if ( m_viewmode == VIEWMODE_PARENT ) m_threadPart->showAll();
+    if ( m_viewmode == VIEWMODE_MAINVIEW ) m_threadPart->showAll();
 
-    insertSearchCombo();    
+    insertSearchCombo();
     QStringList list = parseSearchQuery( SearchCombo->currentText() );
     m_threadPart->findText( SearchCombo->currentText(), rev );
     SearchCombo->setFocus();
 }
 
 /* public slot */
-void KitaThreadView::slotGobackAnchor(){ m_threadPart->slotGobackAnchor(); }
-void KitaThreadView::slotGotoHeader(){ m_threadPart->gotoAnchor( "header", FALSE );}
-void KitaThreadView::slotGotoFooter(){ m_threadPart->slotClickGotoFooter(); }
+void KitaThreadView::slotGobackAnchor() { m_threadPart->slotGobackAnchor(); }
+void KitaThreadView::slotGotoHeader() { m_threadPart->gotoAnchor( "header", FALSE );}
+void KitaThreadView::slotGotoFooter() { m_threadPart->slotClickGotoFooter(); }
 
 // vim:sw=2:
 
 void KitaThreadView::slotComboActivated( int index )
 {
-    if ( index == gotoCombo->count() - 1 )
-    {
+    if ( index == gotoCombo->count() - 1 ) {
         // last
         m_threadPart->gotoAnchor( "footer", FALSE );
-    }
-    else if ( index == 1 )
-    {
+    } else if ( index == 1 ) {
         // kokomade yonda
         m_threadPart->gotoAnchor( "kokomade_yonda", FALSE );
-    }
-    else if ( index != 0 )
-    {
+    } else if ( index != 0 ) {
         QString numText = gotoCombo->text( index );
         numText.truncate( numText.length() - 1 );
         m_threadPart->gotoAnchor( numText, FALSE );
@@ -758,24 +716,28 @@ void KitaThreadView::slotComboActivated( int index )
 
 void KitaThreadView::slotDeleteButtonClicked()
 {
-    if( m_datURL.isEmpty() ) return;
- 
+    if ( m_datURL.isEmpty() ) return ;
+
     int rescode = Kita::DatManager::getResponseCode( m_datURL );
-    int readNum = Kita::DatManager::getReadNum( m_datURL );
-    if( ( rescode != 200 &&  rescode != 206) || readNum >= 900
-      || FavoriteThreads::getInstance()->contains( m_datURL.prettyURL() ) ) {
-        if( QMessageBox::warning( this,
-                                  "Kita",
-                                  i18n( "Do you want to delete Log ?" ),
-                                  QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default )
-            != QMessageBox::Ok ) return;
+    if ( ( rescode != 200 && rescode != 206 )
+            || FavoriteThreads::getInstance() ->contains( m_datURL.prettyURL() ) ) {
+        if ( QMessageBox::warning( this,
+                                   "Kita",
+                                   i18n( "Do you want to delete Log ?" ),
+                                   QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default )
+                != QMessageBox::Ok ) return ;
     }
- 
-    Kita::DatManager::deleteCache( threadURL(), this );
+
+    Kita::DatManager::deleteCache( threadURL() );
     emit closeThreadTab( m_datURL );
     emit updateSubjectTab( m_datURL );
 }
 
+void KitaThreadView::slotCloseButton()
+{
+    emit closeCurrentTab();
+}
+
 /*--------------------------------------------------------*/
 /* These public functions are used for KitaNavi & preview */
 /*--------------------------------------------------------*/
@@ -783,55 +745,53 @@ void KitaThreadView::slotDeleteButtonClicked()
 /*---------------------*/
 /* set data & parse it */
 /*---------------------*/ /* public */
-void KitaThreadView::domAppendData( QString& , int bufnum , int  )
+void KitaThreadView::domAppendData( QString& , int bufnum , int )
 {
-    m_threadPart->showResponses(bufnum,bufnum);
+    m_threadPart->showResponses( bufnum, bufnum );
 }
 
 
 /* public */
 void KitaThreadView::domDeleteRes( int )
-{
-}
+{}
 
 
 /* public */
 void KitaThreadView::domAppendBelt( QString idstr )
 {
-    m_threadPart->insertBeltNode(idstr);
+    m_threadPart->insertBeltNode( idstr );
 }
 
 /* public */
-void KitaThreadView::domSetInnerHTML(const QString& html )
+void KitaThreadView::domSetInnerHTML( const QString& html )
 {
     m_threadPart->setInnerHTML( html );
     showStatusBar( "" );
 }
 
 /* public */
-void KitaThreadView::domApplyChange( QString lbstr,  /* label */
-                                     QString hstr,   /* header */
-                                     QString fstr,   /* footer */
-                                     QString anchor,  /* anchor to jump */
-                                     QString cmbstr /* strings to set combo box */
+void KitaThreadView::domApplyChange( QString labelStr,
+                                     QString headerStr,
+                                     QString footerStr,
+                                     QString anchorToJump,
+                                     QString comboStr
                                    )
 {
 
     /* label, header & footer */
-    if ( hstr != NULL ) m_threadPart->insertHeaderNode( hstr );
-    if ( fstr != NULL ) m_threadPart->insertFooterNode( fstr );
-    if ( cmbstr != NULL ) SearchCombo->insertItem( cmbstr );
-    if ( anchor != NULL ) m_threadPart->gotoAnchor( anchor, FALSE );
-    if ( lbstr != QString::null )
-    {
+    if ( headerStr != NULL ) m_threadPart->insertHeaderNode( headerStr );
+    if ( footerStr != NULL ) m_threadPart->insertFooterNode( footerStr );
+    if ( comboStr != NULL ) SearchCombo->insertItem( comboStr );
+    if ( labelStr != QString::null ) {
         QString str = QString( "<a href=\"%1\">[%2]</a> " )
                       .arg( Kita::DatManager::thread_boardURL( m_datURL ) )
-                      .arg( Kita::DatManager::thread_boardName(m_datURL) ) + lbstr;
+                      .arg( Kita::DatManager::thread_boardName( m_datURL ) ) + labelStr;
         subjectLabel->setText( str );
     }
 
     /* update display */
-    m_threadPart->updateScreen(FALSE,FALSE);
+    m_threadPart->updateScreen( FALSE, FALSE );
+    if ( anchorToJump != NULL ) m_threadPart->gotoAnchor( anchorToJump, FALSE );
 
     updateButton();
     showStatusBar( "" );
