@@ -33,8 +33,8 @@ namespace Kita
 }
 
 /* mode , m_viewmode uses them. */
-enum{
-    VIEWMODE_PARENT,
+enum {
+    VIEWMODE_MAINVIEW,
     VIEWMODE_KITANAVI
 };
 
@@ -57,39 +57,41 @@ public:
     ~KitaThreadView();
     const QString threadName() const;
     const KURL threadURL() const;
+    const KURL datURL() const;
 
-    void setup( const KURL& datURL, int mode );    
+    void setup( const KURL& datURL, int mode );
     void showStatusBar( QString info );
     int getViewMode() { return m_viewmode; }
 
-
     /* for preview and KitaNavi */
     void domAppendData( QString& str, int bufnum, int num );
     void domDeleteRes( int bufnum );
     void domAppendBelt( QString idstr );
-    void domSetInnerHTML(const QString& html );
+    void domSetInnerHTML( const QString& html );
     void domApplyChange( QString lbstr, QString hstr, QString fstr, QString anchor, QString cmbstr );
 
 public slots:
-    void subjectlinkClicked(const QString& URL );
+    virtual void setFocus();
+
+    void subjectlinkClicked( const QString& URL );
     void subjectlinkMClicked( const QString &URL );
     void showThread( const KURL& datURL, int num );
     void setFont( const QFont& font );
-    void slotReloadButton();
-    void slotStopLoading();        
+    void slotReloadButton( int jumpNum = 0 );
+    void slotStopLoading();
     void focusSearchCombo();
-    void slotDeleteButtonClicked();    
+    void slotDeleteButtonClicked();
     void slotSearchNext();
     void slotSearchPrev();
     void slotGobackAnchor();
     void slotGotoHeader();
     void slotGotoFooter();
-    
+
 protected slots:
     void slotDOMNodeActivated( const DOM::Node& node );
     void slotPopupMenu( KXMLGUIClient*, const QPoint&, const KURL&, const QString&, mode_t );
 
-private:        // Private attributes
+private:
     int m_serverTime;
     KURL m_datURL;
     KitaHTMLPart* m_threadPart;
@@ -107,20 +109,17 @@ private:        // Private attributes
 
     void insertSearchCombo();
     void setSubjectLabel( const QString& boardName, const QString& threadName, const QString boardURL );
-    KitaWriteDialog* openDialog( const Kita::PostInfo& info );
     QStringList parseSearchQuery( const QString& input ) const;
     void updateButton();
 
-
 private slots:
     void slotSearchButton();
-    void slotPostStarted( KIO::Job*, const Kita::PostInfo& );
     void slotBookmarkButtonClicked( bool on );
     void slotWriteButtonClicked( QString resstr = QString::null );
-    void slotShowErrorDialog( const QString& input, const KURL& urlOfInput = 0 );
     void slotComboActivated( int index );
     void slotUpdateInfo();
-    void slotSearchPrivate( bool rev );    
+    void slotSearchPrivate( bool rev );
+    void slotCloseButton();
 
 signals:
     void datURLRedirected( const KURL& newDatURL );
@@ -140,6 +139,12 @@ signals:
     void openBoardRequested( const QString& URL, bool useTab );
     void showThreadCompleted(); /* to KitaThreadPart */
     void closeThreadTab( const KURL& url );
+    void closeCurrentTab(); /* to KitaThreadTabWidget */
+
+    /* kita navi */
+    void showKitaNaviByWord( const KURL& , QString );
+    void showWriteView( const KURL& , const QString&, const QString& );
+    void activateThreadView( const KURL& );
 };
 
 namespace Kita
@@ -147,25 +152,28 @@ namespace Kita
     // reimplement KActiveLabel based KTextBrowser
     class KitaSubjectLabel : public KTextBrowser
     {
-
-    Q_OBJECT
+        Q_OBJECT
 
     public:
         KitaSubjectLabel( QWidget *parent, const char * name = 0 );
 
         QSize minimumSizeHint() const;
         QSize sizeHint() const;
+
     private slots:
         void paletteChanged();
         void popupOpenAsNewTab();
         void popupCopyToClipboard();
         void popupFavorites();
+
     protected:
         virtual QPopupMenu * createPopupMenu ( const QPoint & pos );
         virtual void contentsMousePressEvent ( QMouseEvent * e );
         virtual void contentsMouseReleaseEvent ( QMouseEvent * e );
+
     signals:
         void urlMClick( const QString& url );
+
     private:
         QString m_popupURL;
     };
