@@ -17,12 +17,18 @@
 #include "libkita/datmanager.h"
 #include "libkita/parsemisc.h"
 #include "libkita/signalcollection.h"
+#include "libkita/board.h"
+#include "libkita/account.h"
+#include "libkita/kita_misc.h"
 
 #include <ksqueezedtextlabel.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <klineedit.h>
+#include <kparts/browserextension.h>
+#include <kmessagebox.h>
+#include <kio/job.h>
 
 #include <qapplication.h>
 #include <qtextedit.h>
@@ -34,49 +40,44 @@
 #include <qmessagebox.h>
 #include <qtabwidget.h>
 #include <qcheckbox.h>
+#include <qlayout.h>
+ 
+static const char* cookie_title = "񤭹߳ǧ";
+static const char* cookie_message =
+    "Ƴǧ\n"
+    "Ƥ줿Ƥϥԡ¸ѡž礬ޤ\n"
+    "Ƥ˴ؤȯǤƼԤ˵ޤ\n"
+    "\n"
+    "Ǥ餦Ȥƽ񤭹ߤޤ\n";
 
-#include <kio/job.h>
-
-KitaWriteDialogPrivate* KitaWriteDialog::s_private = 0;
-
-KitaWriteDialog::KitaWriteDialog( const KURL& datURL, QWidget* parent, const char* name )
-        : KitaWriteDialogBase( parent, name, WStyle_Customize |  WType_TopLevel | WStyle_DialogBorder | WStyle_Title | WStyle_SysMenu | WStyle_MinMax | Qt::WDestructiveClose )
+KitaWriteDialog::KitaWriteDialog( QWidget* parent, const char* name )
+    : KitaWriteDialogBase( parent, name, 0 ){}
+ 
+void KitaWriteDialog::setup( const KURL& url )
 {
-    QFont font = KitaConfig::font();
-    bodyText->setFont( font );
-    nameLine->setFont( font );
-    nameLabel->setFont( font );
-    mailLine->setFont( font );
-    mailLabel->setFont( font );
+    m_datURL = Kita::ParseMisc::parseURLonly( url );
 
-    faceCombo->clear();
-    faceCombo->insertItem( "" );
-    QStringList list = KitaConfig::asciiArtList();
-    QStringList::iterator it;
-    for ( it = list.begin(); it != list.end(); ++it )
-    {
-        faceCombo->insertItem( *it );
-    }
+    boardNameLabel->setText( Kita::DatManager::thread_boardName( m_datURL ) );
+    threadNameLabel->setText( Kita::DatManager::thread_name( m_datURL ) );
+    threadURLLabel->setText( Kita::DatManager::thread_url( m_datURL ) );
+    
+    /* connect signals */
+    Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
 
-    /* emit when this widget is deactivated */
-    connect( this, SIGNAL( windowDeactivated() ),
-             Kita::SignalCollection::getInstance(), SIGNAL( windowDeactivated() ));
+    connect( buttonOk, SIGNAL( clicked() ),
+	     SLOT( postMessage() ) );
 
-    /* If this widget is active and receives
-       signal isKitaActive, then emit signal kitaIsActive. */
-    connect( Kita::SignalCollection::getInstance(), SIGNAL( isKitaActive() ),
-             this, SLOT( slotIsKitaActive() ) );
+    connect( buttonCancel, SIGNAL( clicked() ),
+	     SLOT( reject() ) );
 
-    connect( this, SIGNAL( kitaIsActive() ),
-             Kita::SignalCollection::getInstance(), SIGNAL( kitaIsActive() ) );
+    /* reload */
+    connect( this, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ),
+             signalCollection, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ) );
 
     connect( faceCombo, SIGNAL( activated( const QString& ) ),
              bodyText, SLOT( insert( const QString& ) ) );
-    /*--------------------*/
-    /* init preview       */
-
-    m_datURL = datURL;
 
+    /* setup preview  */
     connect( qtw, SIGNAL( currentChanged ( QWidget * ) ),
              this, SLOT( slotCurrentChanged ( QWidget * ) ) );
 
@@ -84,15 +85,14 @@ KitaWriteDialog::KitaWriteDialog( const KURL& datURL, QWidget* parent, const cha
     qtw->addTab( m_preview->view(), i18n( "preview" ) );
 
     m_preview->setup( HTMLPART_MODE_KHTML, m_datURL );
-
-    /* move to center */
-    QWidget * desk = QApplication::desktop();
-    QPoint p = QPoint( (desk->width() - width() )/2, (desk->height()-height())/2 );
-    move(p);
 }
 
 KitaWriteDialog::~KitaWriteDialog()
-{}
+{
+    if ( m_preview ) {
+        delete m_preview;
+    }
+}
 
 const QString KitaWriteDialog::name() const
 {
@@ -109,6 +109,18 @@ const QString KitaWriteDialog::body() const
     return bodyText->text();
 }
 
+const KURL KitaWriteDialog::datURL() const
+{
+    return m_datURL;
+}
+
+const Kita::PostInfo KitaWriteDialog::postInfo() const
+{
+    Kita::PostInfo tmpInfo = m_postInfo;
+    fetchPostInfo( &tmpInfo );    
+    return tmpInfo;
+}
+
 void KitaWriteDialog::fetchPostInfo( Kita::PostInfo* storage ) const
 {
     storage->name = name();
@@ -116,50 +128,6 @@ void KitaWriteDialog::fetchPostInfo( Kita::PostInfo* storage ) const
     storage->body = body();
 }
 
-// TODO: Thread饹Ȥ褦˽񤭴
-KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info,
-                                        const KURL& datURL,
-                                        QWidget* parent )
-{
-    if ( ! info.check() ) return 0;
-    if ( ! s_private )
-    {
-        s_private = new KitaWriteDialogPrivate;
-        if ( ! s_private ) return 0;
-    }
-
-    KitaWriteDialog* new_dlg = new KitaWriteDialog( datURL, parent );
-    if ( ! new_dlg ) return 0;
-
-    new_dlg->m_postInfo = info;
-    s_private->m_heaplist.append( new_dlg );
-
-    new_dlg->connect( new_dlg->buttonOk, SIGNAL( clicked() ),
-                      new_dlg, SLOT( postMessage() ) );
-
-    new_dlg->connect( new_dlg->buttonCancel, SIGNAL( clicked() ),
-                      new_dlg, SLOT( reject() ) );
-
-    // set fields
-    new_dlg->nameLine->setText( info.name );
-    new_dlg->mailLine->setText( info.mail );
-    if ( info.mail == "sage" )
-    {
-        new_dlg->sageBox->setChecked( true );
-        new_dlg->m_mailswap = "";
-    }
-    new_dlg->bodyText->setText( info.body );
-
-    new_dlg->boardNameLabel->setText( Kita::DatManager::thread_boardName( datURL ) );
-    new_dlg->threadNameLabel->setText( Kita::DatManager::thread_name( datURL ) );
-    new_dlg->threadURLLabel->setText( Kita::DatManager::thread_url( datURL ) );
-
-    KCompletion* comp = KitaConfig::nameCompletion();
-    new_dlg->nameLine->setCompletionObject( comp );
-
-    new_dlg->setCaption( i18n( "Write in %1" ).arg( Kita::DatManager::thread_name( datURL ) ) );
-    return new_dlg;
-}
 
 static void logPostMessage( const Kita::PostInfo& postInfo,
                             const QString& boardName,
@@ -204,6 +172,11 @@ void KitaWriteDialog::postMessage()
 
     //int mib = QTextCodec::codecForName("CP932")->mibEnum();
     QString postStr = m_postInfo.postStr();
+    if ( Kita::is2ch( bbscgi ) && Kita::Account::isLogged() ) {
+        postStr += "&sid=";
+        postStr += KURL::encode_string( Kita::Account::getSessionID() );
+    }
+
 
     kdDebug() << "query: " << postStr << endl;
     m_array.resize( 0 );
@@ -218,8 +191,6 @@ void KitaWriteDialog::postMessage()
     // TODO: rewrite!
     logPostMessage( m_postInfo, boardNameLabel->text(), threadNameLabel->text(), threadURLLabel->text() );
 
-    emit postStarted( job, m_postInfo );
-
     connect( job, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
              this, SLOT( slotRecieveData( KIO::Job*, const QByteArray& ) ) );
     connect( job, SIGNAL( result( KIO::Job* ) ),
@@ -231,34 +202,34 @@ void KitaWriteDialog::slotRecieveData( KIO::Job*, const QByteArray& data )
     m_array.append( data.data() );
 }
 
-void KitaWriteDialog::slotPostFinished( KIO::Job* job )
+void KitaWriteDialog::slotPostFinished( KIO::Job* )
 {
     QString response = QTextCodec::codecForName( "sjis" ) ->toUnicode( m_array );
     QCString output = QTextCodec::codecForName( "eucJP" ) ->fromUnicode( response );
     kdDebug() << "response: '" << output.data() << "'" << endl;
-    emit postFinished( job );
     KURL bbscgi;
     bbscgi.setProtocol( "http" );
     bbscgi.setHost( m_postInfo.host );
     bbscgi.setPath( m_postInfo.bbscgi );
-    emit postResponse( response, bbscgi );
+    slotShowErrorDialog( response, bbscgi );
 
     m_array.resize( 0 );
-
-    int idx = s_private->m_heaplist.find( this );
-    if ( idx != -1 )
-        close( TRUE );
 }
 
 void KitaWriteDialog::reject()
 {
+    if( body().length() == 0 ){
+	emit closeCurrentTab(); /* to KitaWriteTabWidget */
+	return;
+    }
+    
     switch ( QMessageBox::warning( this, "Kita",
                                    i18n( "If you close this dialog, you will lose text.\n"
                                          "Do you want to close?" ),
                                    QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default ) )
     {
     case QMessageBox::Ok:
-        close( TRUE );
+	emit closeCurrentTab(); /* to KitaWriteTabWidget */
         break;
     case QMessageBox::Cancel:
         // do nothing
@@ -268,6 +239,8 @@ void KitaWriteDialog::reject()
 
 // vim:sw=2:
 
+/* public slot */
+void KitaWriteDialog::slotEnableWriting( bool enable ){ buttonOk->setEnabled( enable ); }
 
 /* update preview screen */
 void KitaWriteDialog::slotCurrentChanged ( QWidget * w )
@@ -290,14 +263,86 @@ void KitaWriteDialog::slotCurrentChanged ( QWidget * w )
 }
 
 
-/* when window is deactivated, emit signal to popup */ /* protected */
-void KitaWriteDialog::windowActivationChange ( bool  )
+void KitaWriteDialog::clear( const Kita::PostInfo& info )
 {
-    if(!isActiveWindow()) emit windowDeactivated();
-}
+    m_postInfo = info;
+    
+    QFont font = KitaConfig::threadFont();
+    bodyText->setFont( font );
+    nameLine->setFont( font );
+    nameLabel->setFont( font );
+    mailLine->setFont( font );
+    mailLabel->setFont( font );
+    
+    faceCombo->clear();
+    faceCombo->insertItem( "" );
+    QStringList list = KitaConfig::asciiArtList();
+    QStringList::iterator it;
+    for ( it = list.begin(); it != list.end(); ++it )
+    {
+        faceCombo->insertItem( *it );
+    }
 
-/* private slot */
-void KitaWriteDialog::slotIsKitaActive()
+    nameLine->setText( info.name );
+    mailLine->setText( info.mail );
+    if ( m_postInfo.mail == "sage" )
+    {
+        sageBox->setChecked( true );
+        m_mailswap = "";
+    }
+
+    bodyText->setText( info.body );
+
+    KCompletion* comp = KitaConfig::nameCompletion();
+    nameLine->setCompletionObject( comp );
+
+    qtw->setCurrentPage( 0 );
+}
+ 
+void KitaWriteDialog::slotShowErrorDialog( const QString& input, const KURL& )
 {
-    if(isActiveWindow()) emit kitaIsActive();
+    QTextCodec * eucjpCodec = QTextCodec::codecForName( "euc-jp" );
+    KParts::URLArgs argdummy;
+    
+    kdDebug() << "'" << input << "'" << endl;
+    Kita::WriteResult writeResult( input );
+
+    kdDebug() << "code = " << writeResult.code() << endl;
+    switch ( writeResult.code() )
+    {
+	
+    case Kita::K2ch_Unknown:  // probably OK.
+
+	/* reload */
+        emit openURLRequest( m_datURL, argdummy );	
+	
+	/* clear */
+	m_postInfo.body = QString::null;
+	clear( m_postInfo );
+
+	emit closeCurrentTab(); /* to KitaWriteTabWidget */
+	
+        break;
+	
+    case Kita::K2ch_True:
+    case Kita::K2ch_False:
+    case Kita::K2ch_Check:
+        break;
+	
+    case Kita::K2ch_Error:
+	KMessageBox::error( 0, writeResult.message(), writeResult.title() );
+        break;
+	
+    case Kita::K2ch_Cookie:
+        if ( KMessageBox::questionYesNo( 0, eucjpCodec->toUnicode( cookie_message ),
+                                         eucjpCodec->toUnicode( cookie_title ) )
+                == KMessageBox::Yes )
+        {
+            postMessage();
+        }
+        break;
+
+    default:
+        break;
+    }
 }
