@@ -20,12 +20,19 @@ template <class type> class QPtrList;
 class KitaWriteDialogPrivate;
 class KitaWriteDialog;
 class KitaHTMLPart;
+class QVBoxLayout;
+class QTabWidget;
 
 namespace Kita
 {
     class Access;
 }
 
+namespace KParts
+{
+    class URLArgs;
+}
+
 /**
  * 
  * Hideki Ikemoto
@@ -34,7 +41,7 @@ class KitaWriteDialog : public KitaWriteDialogBase
 {
     Q_OBJECT
 public:
-    KitaWriteDialog( const KURL& datURL, QWidget* parent = 0, const char* name = 0 );
+    KitaWriteDialog( QWidget* parent = 0, const char* name = 0 );
     virtual ~KitaWriteDialog();
     const QString name() const;
     const QString mail() const;
@@ -42,13 +49,18 @@ public:
 
     virtual bool error() { return false; };
 
-    static KitaWriteDialog* open( const Kita::PostInfo& info, const KURL& datURL, QWidget* parent );
-
+    const KURL datURL() const;
+    void clear( const Kita::PostInfo& info );
+    const Kita::PostInfo postInfo() const;
+    void setup( const KURL& url );
+    
 public slots:
+    void slotEnableWriting( bool enable );
     void postMessage();
 
 private slots:
     void slotCurrentChanged ( QWidget * w );
+    void slotShowErrorDialog( const QString& input, const KURL& ); 
 
 signals:
     void postStarted( KIO::Job*, const Kita::PostInfo& );
@@ -57,7 +69,6 @@ signals:
 
 protected:
     Kita::PostInfo m_postInfo;
-    void windowActivationChange( bool );
 
 protected slots:
     virtual void reject();
@@ -75,18 +86,9 @@ private:
 private slots:
     void slotRecieveData( KIO::Job*, const QByteArray& );
     void slotPostFinished( KIO::Job* );
-    void slotIsKitaActive();    
 
 signals:
-    void windowDeactivated();
-    void isKitaActive();
-    void kitaIsActive();          
-
-};
-
-class KitaWriteDialogPrivate
-{
-public:
-    QPtrList<KitaWriteDialog> m_heaplist;
+    void openURLRequest( const KURL&, const KParts::URLArgs& );
+    void closeCurrentTab();
 };
 #endif
