@@ -41,6 +41,7 @@ ThreadListView::ThreadListView( QWidget* parent, const char* name )
     subjectList->addColumn( i18n( "ReadNum" ) );
     subjectList->addColumn( i18n( "Unread" ) );
     subjectList->addColumn( i18n( "Since" ) );
+    subjectList->addColumn( i18n( "Thread's speed" ) );
 
     QHeader *h = subjectList->header();
     h->setResizeEnabled( FALSE, Col_Mark );
@@ -183,11 +184,15 @@ int ThreadListViewItem::compare( QListViewItem* i, int col, bool ascending ) con
     case Col_ResNum:
     case Col_Read:
     case Col_Unread:
-        return QString::localeAwareCompare( i->key( col, ascending ), key( col, ascending ) );
+        return i->key( col, ascending ).toInt() - key( col, ascending ).toInt();
+    case Col_ID:
+        return key( col, ascending ).toInt() - i->key( col, ascending ).toInt();
     case Col_Mark:
         return QString::localeAwareCompare( i->key( Col_MarkOrder, ascending ), key( Col_MarkOrder, ascending ) );
     case Col_Since:
         return QString::localeAwareCompare( i->key( col, ascending ), key( col, ascending ) );
+    case Col_Speed:
+        return static_cast<int>( i->key( col, ascending ).toDouble() * 1000 - key( col, ascending ).toDouble() * 1000 );
     default:
         return QString::localeAwareCompare( key( col, ascending ), i->key( col, ascending ) );
     }
